@ECHO OFF
:: :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: OptimSilentUninstall.bat
::
::    Licensed Materials - Property of IBM
::    "Restricted Materials of IBM"
::
::    5724-U38, 5724-U39, 5724-U48
::
::     Copyright IBM Corp. 2020, 2021 All Rights Reserved
::
::     Copyright 2020, 2021 UNICOM Systems, Inc. - All Rights Reserved
::
::    US Government Users Restricted Rights - Use, duplication or
::    disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
::
:: Windows batch file, called by Installation Manager, to silently uninstall the
:: Optim server feature of the Optim Runtime Services installer.
:: 
:: Make a copy of the following files, place them in a scripts directory, then
:: modify them to suit your installation. This directory will dynamically be 
:: determined at execution time and set to OPTIM_SCRIPTS environment variable.
:: 1) autoinstall.cmd                     Optional driver script for automation
:: 2) SilentInstall.bat                   The main installation script
:: 3)    install{component}.xml           Used by IM to install an Optim component
:: 4)    uninstall{component}.xml         Used by IM to uninstall an Optim component
:: 5)    OptimSilentUninstall.bat         Called by IM to uninstall an Optim 11.3.0.x server
:: **** Copy, but do not modify, the following license files **** 
:: The license files are provided separately from the installation image.
:: 1)    OPDG.LIC                         Optim Data Growth License
:: 2)    OPTDM.LIC                        Optim Test data Management License
:: 3)    OPDP.LIC                         Optim Data Privacy License
:: Then start the process by running SilentInstall.bat
:: ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
@ECHO .
@ECHO -- Entering OptimSilentUninstall.bat --
:: Get the path to the current batch file
SET OPTIM_SCRIPTS=%~dp0

:: Specify the base installation directory (ending in Optim}
:: Do NOT include rt\bin to the path.
IF "%OPTIM_ROOT%." == "." (
   SET _RC=44
   @ECHO The environment variable OPTIM_ROOT must be set in SilentInstall.bat.
   GOTO END
)

:: The fully qualified Optim uninstallation program that is laid down by
:: the Optim Runtime Services installer.  The Optim uninstall program will be
:: located in the "Uninstall_IBM Optim" subdirectory of the Optim Runtime Services 
:: installation.  The default location would be:
::
:: C:\IBM\InfoSphere\Optim\Uninstall_IBM Optim\Uninstall IBM Optim.exe
::
:: If OPTIM_ROOT is correct, this should not need to be changed 
SET OPTIM_UNINSTALLER=%OPTIM_ROOT%\Uninstall_IBM Optim\Uninstall IBM Optim.exe

:: Remove all old logs
:: %OPTIM_SCRIPTS% contains a trailing "\"
IF EXIST "%OPTIM_SCRIPTS%SEA.LOG"                           DEL "%OPTIM_SCRIPTS%SEA.LOG"
IF EXIST "%OPTIM_ROOT%\IBM_InfoSphere_Optim_InstallLog.log" DEL "%OPTIM_ROOT%\IBM_InfoSphere_Optim_InstallLog.log"
IF EXIST "%TEMP%\IAOptimInstall.log"                        DEL "%TEMP%\IAOptimInstall.log"
IF EXIST "%TEMP%\IADebugInfoOptim"                          DEL "%TEMP%\IADebugInfoOptim"
IF EXIST "%TEMP%\jusched.log"                               DEL "%TEMP%\jusched.log"
IF EXIST "%OPTIM_ROOT%\Uninstall_IBM Optim\Logs\IBM_InfoSphere_Optim_InstallLog.log" DEL  "%OPTIM_ROOT%\Uninstall_IBM Optim\Logs\IBM_InfoSphere_Optim_InstallLog.log" 

:: Ensure the Optim Server feature uninstaller exists
IF NOT EXIST "%OPTIM_UNINSTALLER%" @ECHO Optim server feature uninstaller %OPTIM_UNINSTALLER% not found!
IF NOT EXIST "%OPTIM_UNINSTALLER%" GOTO END

SET IBM_JAVA_OPTIONS="-Dos.name=Windows 7 -Djava.io.tempdir=%IATEMPDIR%"

@ECHO Uninstalling Optim Server...
"%OPTIM_UNINSTALLER%" -Dlax.nl.env.tmp="%IATEMPDIR%"
SET _RC=%ERRORLEVEL%
@ECHO Optim uninstall completed with RC %_RC%

:END
CD %OPTIM_SCRIPTS%
IF EXIST "%OPTIM_ROOT%\rt\bin\RTBUILD.H"     @ECHO *** Optim was not uninstalled successfully ***
IF NOT EXIST "%OPTIM_ROOT%\rt\bin\RTBUILD.H" @ECHO Optim was uninstalled successfully.
@ECHO -- Exiting OptimSilentUninstall.bat --
EXIT /B %_RC%