#!/bin/bash
## #############################################################################
# OptimSilentUninstall.sh
#     Licensed Materials - Property of IBM
#    "Restricted Materials of IBM"
#
#    5724-U38, 5724-U39, 5724-U48
#
#     Copyright IBM Corp. 2008, 2021 All Rights Reserved
#
#     Copyright 2014, 2021 UNICOM Systems, Inc. - All Rights Reserved
#
#    US Government Users Restricted Rights - Use, duplication or
#    disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# Unix shell script to silently uninstall the Optim server feature of the 
# Optim Runtime Services installer. 
# Make a copy of the following files, place them in a scripts directory, then
# modify them to suit your installation. This directory will dynamically be 
# determined at execution time and set to OPTIM_SCRIPTS environment variable.
# 1) autoinstall.sh                     Optional driver script for automation
# 2) SilentInstall.sh                   The main installation script
# 3)    install{component}.xml          Used by IM to install an Optim component
# 4)    uninstall{component}.xml        Used by IM to uninstall an Optim component
# 5)    OptimSilentUninstall.sh         Called by IM to uninstall an Optim 11.3.0.x server
# **** Copy, but do not modify, the following license files ****
# The license files are provided separately from the installation image.
# 1)    OPDG.LIC                         Optim Data Growth License
# 2)    OPTDM.LIC                        Optim Test data Management License
# 3)    OPDP.LIC                         Optim Data Privacy License
# Then start the process by running SilentInstall.sh
## ##############################################################################
echo -- Entering OptimSilentUninstall.sh --
# The files listed above should all be copied to a scripts directory
# For example /home/optim/scripts
# Get the path to the current batch file
OPTIM_SCRIPTS=${OPTIM_SCRIPTS:-"$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"}
export OPTIM_SCRIPTS

echo Using OPTIM_SCRIPTS directory: ${OPTIM_SCRIPTS}

# Specify the base installation directory (ending in Optim}
if [ -z "${OPTIM_ROOT}" ] ; then
   _RC=44
   echo The environment variable OPTIM_ROOT must be set in SilentInstall.sh
   echo Optim server feature uninstaller completed with return code ${_RC}.
   exit ${_RC}
fi

# Starting with 11.3.0.8, the installation log location
if [ -z "${OPTIM_INSTALL_LOGS}" ] ; then
   _RC=66
   echo The environment variable OPTIM_INSTALL_LOGS must be set in SilentInstall.sh
   echo Optim server feature uninstaller completed with return code ${_RC}.
   exit ${_RC}
fi

# The fully qualified Optim uninstallation program that is laid down by
# the Optim Runtime Services installer.  The Optim server uninstallation program
# will be located in the OPTIM_ROOT directory.
# The default location would be:
#
# ~/IBM/InfoSphere/Optim/Uninstall_Optim/uninstaller
#
# If OPTIM_ROOT is correct, this should not need to be changed
OPTIM_UNINSTALLER=${OPTIM_ROOT}/Uninstall_Optim/uninstaller
export OPTIM_UNINSTALLER

# Ensure the OptimLogs directory exists
if [ ! -d "${OPTIM_INSTALL_LOGS}" ]; then mkdir "${OPTIM_INSTALL_LOGS}" ; fi 

if [ ! -f "${OPTIM_UNINSTALLER}" ] ; then
   _RC=67
   echo The Optim Server feature uninstaller ${OPTIM_UNINSTALLER} not found.
   echo Optim server feature uninstaller completed with return code ${_RC}.
   echo -- Exiting OptimSilentUninstall --
   exit ${_RC}
fi

echo Uninstalling Optim server feature...
${OPTIM_UNINSTALLER}
_RC=$?

if [ ! -f "${OPTIM_ROOT}/rt/bin/RTBUILD.H" ] ; then   echo Optim server feature was uninstalled successfully! ; fi
if [ -f "${OPTIM_ROOT}/rt/bin/RTBUILD.H" ] ; then 
   _RC=98
   echo  *** Optim server feature failed to uninstall ***
fi
echo Optim server feature uninstaller completed with return code ${_RC}.
echo -- Exiting OptimSilentUninstall.sh --
exit ${_RC}
