@ECHO OFF
:: :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: SilentInstall.bat
::
::    Licensed Materials - Property of IBM
::    "Restricted Materials of IBM"
::
::    5724-U38, 5724-U39, 5724-U48
::
::     Copyright IBM Corp. 2008, 2021 All Rights Reserved
::
::     Copyright 2014, 2021 UNICOM Systems, Inc. - All Rights Reserved
::
::    US Government Users Restricted Rights - Use, duplication or
::    disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
::
:: Windows batch file to silently install and/or uninstall the Optim components:
:: Optim Designer, Optim Runtime Services, Optim Web Applications.  It can also
:: uninstall WebSphere Application Server Community Edition (WAS-CE) (11.3.0.8 only)
:: 
:: Refer to optimutil.cmd for instructions.
:: 
:: ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
SETLOCAL EnableDelayedExpansion
SETLOCAL EnableExtensions
@ECHO .
@ECHO -- Entering SilentInstall.bat --
:: The files listed above should all be copied to a scripts directory
:: For example, C:\IBM\SCRIPTS\
:: Get the path to the current batch file
:: NOTE: %OPTIM_SCRIPTS% will contain a trailing "\"
SET "OPTIM_SCRIPTS=%~dp0"

@ECHO Using OPTIM_SCRIPTS directory: %OPTIM_SCRIPTS%

:: Set to the current major version (e.g., 11.7.0.0 etc.)
IF "%MAJOR_VERSION%." == "."           SET MAJOR_VERSION=11.7.0.0
:: Set to the major version being uninstalled (e.g., 11.3.0.0, 11.7.0.0)
IF "%MAJOR_UNINSTALL_VERSION%." == "." SET MAJOR_UNINSTALL_VERSION=11.3.0.0
:: Set to the current version (e.g., 11.3.0.8 etc.)
IF "%CURRENT_VERSION%." == "."         SET CURRENT_VERSION=11700

:: Set to 1 to uninstall/install a component
IF "%UNINSTALL_DESIGNER%." == "."      SET UNINSTALL_DESIGNER=1
IF "%INSTALL_DESIGNER%." == "."        SET INSTALL_DESIGNER=1
IF "%UNINSTALL_RUNTIME%." == "."       SET UNINSTALL_RUNTIME=1
IF "%INSTALL_RUNTIME%." == "."         SET INSTALL_RUNTIME=1
IF "%UNINSTALL_SHARED%." == "."        SET UNINSTALL_SHARED=1
IF "%INSTALL_SHARED%." == "."          SET INSTALL_SHARED=1

REM Internal Use Only
IF "%UNINSTALL_JAVA%." == "."          SET UNINSTALL_JAVA=0
IF "%INSTALL_JAVA%." == "."            SET INSTALL_JAVA=0
IF "%UNINSTALL_TEST%." == "."          SET UNINSTALL_TEST=0
IF "%INSTALL_TEST%." == "."            SET INSTALL_TEST=0
:: Must be false.  A value of true is for internal use only
IF "%USE_OPTIM_JAVA%." == "."          SET USE_OPTIM_JAVA=false

:: Specify the base installation directory (ending in Optim}
:: Do NOT include rt\bin to the path.
IF "%OPTIM_ROOT%." == "."             SET "OPTIM_ROOT=C:\IBM\InfoSphere\Optim"

:: Specify the value for JRE_HOME (don't include bin)
IF "%JRE_HOME%." == "."               SET "JRE_HOME=C:\Program Files (x86)\AdoptOpenJDK\jdk-8.0.272.10-openj9\jre"
:: The fully qualified path to the JVM
IF "%JVM_PATH%." == "."               SET "JVM_PATH=C:\Program Files (x86)\AdoptOpenJDK\jdk-8.0.272.10-openj9\jre\bin\j9vm\jvm.dll"
:: Specify the location of the Java library RELATIVE to the install directory
:: of Designer or Runtime Services
:: A relative directory can only be created when the JVM and Optim are on the
:: same drive. A JUNCTION may be used to create a soft link to a JVM on a 
:: different drive.
:: For example: mklink /j "D:\Path to alias for JRE" "C:\Program Files\Java\jre"
IF "%JVM_LOCATION%." == "."           SET "JVM_LOCATION=..\..\..\..\Program Files (x86)\AdoptOpenJDK\jdk-8.0.272.10-openj9\jre\bin\j9vm\jvm.dll"

:: Specify the shared installation directory used by all Installation Manager
:: eclipse based products. This is NOT the same as the Optim Shared directory.
IF "%SDP_SHARED%." == "."             SET "SDP_SHARED=C:\Program Files\IBM\Shared"

:: IF Optim Provides a launch pad, specify the directory that contains the
:: expanded launchpad repository 
:: (it must contain the diskTag.inf)
:: The shared directory
:: IF "%OPTIM_LAUNCHPAD%." == "."        SET OPTIM_LAUNCHPAD=C:\Optim\repo\disk1

:: Specify the directory that contains the expanded fix pack repository 
:: (it must contain the repository.config)
IF "%OPTIM_FIXPACK_DESIGNER%." == "." SET OPTIM_FIXPACK_DESIGNER=C:\Optim\%CURRENT_VERSION%\designer%CURRENT_VERSION%_update
IF "%OPTIM_FIXPACK_RUNTIME%." == "."  SET OPTIM_FIXPACK_RUNTIME=C:\Optim\%CURRENT_VERSION%\runtime%CURRENT_VERSION%_update
:: 11.3.0.8 Only
IF "%OPTIM_FIXPACK_WASCE%." == "."    SET OPTIM_FIXPACK_WASCE=C:\Optim\%CURRENT_VERSION%\wasce%CURRENT_VERSION%_update
IF "%OPTIM_FIXPACK_WEB%." == "."      SET OPTIM_FIXPACK_WEB=C:\Optim\%CURRENT_VERSION%\web%CURRENT_VERSION%_update

:: Internal Use Only
IF "%OPTIM_FIXPACK_JAVA%." == "."     SET OPTIM_FIXPACK_JAVA=C:\Optim\%CURRENT_VERSION%\java%CURRENT_VERSION%
IF "%OPTIM_FIXPACK_TEST%." == "."     SET OPTIM_FIXPACK_TEST=C:\Optim\%CURRENT_VERSION%\test%CURRENT_VERSION%

:: Specify information to shutdown the Web Application Server
IF "%WEB_USER%." == "."               SET WEB_USER=system
IF "%WEB_PASSWORD%." == "."           SET WEB_PASSWORD=manager
IF "%JAVA_HOME%." == "."              SET "JAVA_HOME=C:\Program Files (x86)\AdoptOpenJDK\jdk-8.0.272.10-openj9"

:: (Windows Only) Set to true to create desktop shortcuts
IF "%CREATE_DESKTOP_SHORTCUTS%." == "."              SET CREATE_DESKTOP_SHORTCUTS=true
:: (Windows Only) Set to true to create Optim file associations (requires write access to the Windows Registry)
IF "%CREATE_OPTIM_FILE_ASSOCIATIONS%." == "."        SET CREATE_OPTIM_FILE_ASSOCIATIONS=true
:: Set to true to populate the OptimConfigClient.ini file with Optim entries from the Windows Registry 
:: WARNING: This action will wipe out any existing entries to the existing OptimConfigClient.ini 
:: (requires read access to the Windows Registry)
:: You can also select the Optim Config Population start menu option to run this step later 
IF "%POPULATE_OPTIM_CONFIG%." == "."                  SET POPULATE_OPTIM_CONFIG=false
:: Specify the location of the OptimConfigClient.pst file installed by Runtime Services
IF "%OPTIM_CONFIG_CLIENT_LOCATION%." == "."           SET "OPTIM_CONFIG_CLIENT_LOCATION=%OPTIM_ROOT%\rt\OptimConfigClient.pst"
:: Specify the location of the OptimConfigServer.pst file installed by Runtime Services
IF "%OPTIM_CONFIG_SERVER_LOCATION%." == "."           SET "OPTIM_CONFIG_CLIENT_LOCATION=%OPTIM_ROOT%\rt\OptimConfigServer.pst"

:: Set to true to delete the OptimConfig*.pst files at uninstall times. 
:: WARNING: Only set to true if do not plan on installing another instance of 
::        Optim on this computer
IF "%DELETE_OPTIM_CONFIG_FILES%" == "."               SET DELETE_OPTIM_CONFIG_FILE=false
    
:: (Windows Only) Set to true to delete the Optim entries in the Windows registry. 
:: WARNING: Only set to true if do not plan on installing another instance of 
:: Optim on this computer
IF "%DELETE_OPTIM_WINDOWS_REGISTRY_ENTRIES%" == "."  SET DELETE_OPTIM_WINDOWS_REGISTRY_ENTRIES=false

:: Set true if you have one or more Optim Permanent License files
IF "%OPTIM_PERMANENT_LICENSE%." == "."               SET OPTIM_PERMANENT_LICENSE=false
:: If OPTIM_PERMANENT_LICENSE is true, set to true if you have an Optim Data Grown Permanent license
IF "%OPTIM_PERMANENT_DG_LICENSE%." == "."            SET OPTIM_PERMANENT_DG_LICENSE=false
:: If OPTIM_PERMANENT_DG_LICENSE is true, set to the directory (not file name) of the Optim Data Grown Permanent license file
IF "%OPTIM_PERMANENT_DG_LICENSE_DIRECTORY%." == "."  SET "OPTIM_PERMANENT_DG_LICENSE_DIRECTORY= "
:: If OPTIM_PERMANENT_LICENSE is true, set to true if you have an Optim Test Data Management Permanent license
IF "%OPTIM_PERMANENT_TDM_LICENSE%." == "."           SET OPTIM_PERMANENT_TDM_LICENSE=false
:: If OPTIM_PERMANENT_TDM_LICENSE is true, set to the directory (not file name) of the Optim Test Data Management Permanent license file
IF "%OPTIM_PERMANENT_TDM_LICENSE_DIRECTORY%." == "." SET "OPTIM_PERMANENT_TDM_LICENSE_DIRECTORY= "
:: If OPTIM_PERMANENT_LICENSE is true, set to true if you have an Optim Data Privacy Permanent license
IF "%OPTIM_PERMANENT_DP_LICENSE%." == "."            SET OPTIM_PERMANENT_DP_LICENSE=false
:: If OPTIM_PERMANENT_DP_LICENSE is true, set to the directory (not file name) of the Optim Data Privacy Permanent license file
IF "%OPTIM_PERMANENT_DP_LICENSE_DIRECTORY%." == "."  SET "OPTIM_PERMANENT_DP_LICENSE_DIRECTORY= "

:: Set the target OS. For
:: Windows [any bitness] specify win32
IF "%TARGET_OS%." == "."              SET TARGET_OS=win32
:: Set the target windowing system. For
:: Windows [any bitness] specify win32
IF "%TARGET_WS%." == "."              SET TARGET_WS=win32
:: Set application architecture. For
:: Windows: must be x86_64 for 64 bit
IF "%TARGET_ARCH%." == "."            SET TARGET_ARCH=x86_64

:: Specify the IBM Installation Manager eclipse directory
IF "%IM_ROOT%." == "."                SET "IM_ROOT=C:\IBM\Program Files\Installation Manager\eclipse"
IF "%_IM_TOOL%." == "."               SET "_IM_TOOL=%IM_ROOT%\tools\imcl.exe"
:: Set to admin or nonAdmin depending on how Installation Manager is installed
IF "%IM_INSTALL_MODE%." == "."        SET IM_INSTALL_MODE=admin

:: Set TEMP here to change the temporary directory used during installation.
IF "%TEMP%." == "."                   SET "TEMP=C:\TEMP"

:: Set this to true to print debug information for the IA installer (11.3.0.8 or earlier)
IF "%LAX_DEBUG%." == "."              SET LAX_DEBUG=false

:: We don't need to test for Administrator access in 11.7
IF "%MAJOR_UNINSTALL_VERSION%." == "11.3.0.0." (
   REM Ensure the cmd window has administrative access
   net session >nul 2>&1
   SET _RC=%ERRORLEVEL%
   IF NOT %_RC% == 0 (
      @ECHO Optim recommends that you install with administrative access.
      @ECHO To do this, start this command prompt with "Run as administrator".
      @ECHO To disable this test, comment out the "net session" test and set _RC=0  
      GOTO :EXIT
   )
) ELSE (
   IF NOT "%MAJOR_UNINSTALL_VERSION%." == "11.7.0.0." (
      @ECHO MAJOR_UNINSTALL_VERSION must be 11.3.0.0 or 11.7.0.0, found %MAJOR_UNINSTALL_VERSION%.
      REM Ensure MAJOR_UNINSTALL_VERSION is valid if we are doing an uninstall
      IF "%UNINSTALL_DESIGNER%" == "1" (
         SET _RC=99
         GOTO :EXIT
      )
      IF "%UNINSTALL_RUNTIME%" == "1" (
         SET _RC=99
         GOTO :EXIT
      )
      IF "%UNINSTALL_SHARED%" == "1" (
         SET _RC=99
         GOTO :EXIT
      )
   )
)
:: ::::::::::::::::::::::::::::::::::::::::::::::::::
:: No changes should be needed below this line
:: ::::::::::::::::::::::::::::::::::::::::::::::::::
:: A valid installed JVM is required to install and run Optim
IF "%INSTALL_DESIGNER%" == "1" (
   IF NOT EXIST "%JVM_PATH%" (
      @ECHO Can not find the JVM %JVM_PATH%
      @ECHO You must set JVM_PATH to a valid jvm.dll
      SET _RC=9
      GOTO :EXIT
   )
)
IF "%INSTALL_RUNTIME%" == "1" (
   IF NOT EXIST "%JVM_PATH%" (
      @ECHO Can not find the JVM %JVM_PATH%
      @ECHO You must set JVM_PATH to a valid jvm.dll
      SET _RC=9
      GOTO :EXIT
   )
)

IF "%INSTALL_TEST%" == "1" (
   IF NOT EXIST "%JVM_PATH%" (
      @ECHO Can not find the JVM %JVM_PATH%
      @ECHO You must set JVM_PATH to a valid jvm.dll
      SET _RC=9
      GOTO :EXIT
   )
)

:: 11.3.0.8 Only
SET WEB_STOP=shutdown.bat
SET "WEB_BIN=%OPTIM_ROOT%\shared\WebSphere\AppServerCommunityEdition\bin"
:: 11.7 and higher
SET "_WEB_BIN=%OPTIM_ROOT%\shared\web\app"
SET _WEB_PGM=internal
SET _WEB_PARM=liberty.cmd
SET _WEB_STATUS=status
SET _WEB_START=start
SET _WEB_STOP=stop

SET TEST_DESIGNER=0
SET TEST_RUNTIME=0
SET TEST_SHARED=0
IF "%INSTALL_DESIGNER%" == "1" (
   SET TEST_DESIGNER=1
)
IF "%UNINSTALL_DESIGNER%" == "1" (
   SET TEST_DESIGNER=1
)
IF "%INSTALL_RUNTIME%" == "1" (
   SET TEST_RUNTIME=1
)
IF "%UNINSTALL_RUNTIME%" == "1" (
   SET TEST_RUNTIME=1
)
IF "%INSTALL_SHARED%" == "1" (
   SET TEST_SHARED=1
)
IF "%UNINSTALL_SHARED%" == "1" (
   SET TEST_SHARED=1
)

REM Internal Use Only
SET TEST_JAVA=0
IF "%INSTALL_JAVA%" == "1" (
   SET TEST_JAVA=1
)
IF "%UNINSTALL_JAVA%" == "1" (
   SET TEST_JAVA=1
)

:: Is a launch pad defined
IF NOT "%OPTIM_LAUNCHPAD%." == "." (
   :: Ensure the launch pad repository can be found
   IF NOT EXIST "%OPTIM_LAUNCHPAD%\diskTag.inf"  (
      SET _RC=9
      @ECHO The Optim Launchpad repository %OPTIM_LAUNCHPAD% was not found or does not contain the diskTag.inf file.
      GOTO :EXIT
   )
)

if "%INSTALL_DESIGNER%" == "1" (
   REM Ensure the fix pack repository can be found
   IF NOT EXIST "%OPTIM_FIXPACK_DESIGNER%\repository.config" (
      SET _RC=10
      @ECHO The Optim Fix Pack repository %OPTIM_FIXPACK_DESIGNER% was not found or does not contain the repository.config file.
      GOTO :EXIT
   )
)

:: Determine if Designer is installed to determine if an uninstall is needed
IF "%TEST_DESIGNER%" == "1" (
   @ECHO Testing if %OPTIM_ROOT%\designer\eclipse.exe exists...
   IF NOT EXIST "%OPTIM_ROOT%\designer\eclipse.exe" (
      @ECHO Designer is not installed at %OPTIM_ROOT%\designer. Skipping the uninstall step.
      SET UNINSTALL_DESIGNER=0
   )
)

if "%INSTALL_RUNTIME%" == "1" (
   REM Ensure the fix pack repository can be found
   IF NOT EXIST "%OPTIM_FIXPACK_RUNTIME%\repository.config" (
      SET _RC=10
      @ECHO The Optim Fix Pack repository %OPTIM_FIXPACK_RUNTIME% was not found or does not contain the repository.config file.
      GOTO :EXIT
   )
)

:: The following is needed for an install and uninstall
IF "%TEST_RUNTIME%" == "1" (
   @ECHO Testing if %OPTIM_ROOT%\rt\bin\pr0shut.exe exists...
   IF EXIST "%OPTIM_ROOT%\rt\bin\pr0shut.exe" (
      @ECHO Determining if Optim is running....
      CALL "%OPTIM_ROOT%\rt\bin\pr0shut.exe" /STOPSYSTEM
      SET _RC=!ERRORLEVEL!
      IF NOT "!_RC!." == "0." (
         @ECHO "Optim is still running.  Please shutdown Optim, then try again."
         GOTO :EXIT
      )
      @ECHO Optim is not running.
   ) ELSE (
      @ECHO "Runtime Services is not installed at %OPTIM_ROOT%\rt\bin. Skipping the uninstall step."
      SET UNINSTALL_RUNTIME=0
   )
   REM The OptimSilentInstall.bat and OptimSilentSilentUninstall.bat 
   REM is only used in 11.3.0.x
   IF "%MAJOR_UNINSTALL_VERSION%." == "11.3.0.0" (
       REM Only uninstall is supported with this version of SilentInstall
       SET "OPTIM_SERVER_INSTALLER="

       REM Specify the OptimSilentUninstall.bat script file exists
       REM In Windows, OPTIM_SCRIPTS ends with a "\" 
       SET OPTIM_SERVER_UNINSTALLER=%OPTIM_SCRIPTS%OptimSilentUninstall.bat

       REM Ensure the the OptimSilentUninstall.bat script file exists
       IF NOT EXIST "!OPTIM_SERVER_UNINSTALLER!"  (
          SET _RC=12
          @ECHO The Optim Server Uninstaller script file !OPTIM_SERVER_UNINSTALLER! was not found.
          GOTO :EXIT
        )
   ) ELSE (
      REM Not used in 11.7
      SET "OPTIM_SERVER_INSTALLER= "
      SET "OPTIM_SERVER_UNINSTALLER= "
   )
)

IF "%INSTALL_SHARED%" == "1" (
   IF NOT EXIST %OPTIM_FIXPACK_WEB%\repository.config (
      SET _RC=10
      @ECHO "The Optim repository %OPTIM_FIXPACK_WEB% was not found or does not contain the repository.config file."
      GOTO :EXIT
   )
   IF %_SOA_VER% == "11.3.0.8" (
      IF NOT EXIST %OPTIM_FIXPACK_WASCE%\repository.config (
         SET _RC=10
         @ECHO "The Optim repository %OPTIM_FIXPACK_WASCE% was not found or does not contain the repository.config file."
         GOTO :EXIT
      )
   )
)

REM Internal Use Only
IF "%INSTALL_JAVA%" == "1" (
   IF NOT EXIST %OPTIM_FIXPACK_JAVA%\repository.config (
      SET _RC=10
      @ECHO "The Optim repository %OPTIM_FIXPACK_JAVA% was not found or does not contain the repository.config file."
      GOTO :EXIT
   )
)

:: The following is needed for an install and uninstall
IF "%TEST_SHARED%" == "1" (
   IF NOT EXIST "%OPTIM_ROOT%\shared\web\app\optim.unified.web.app.war" (
      @ECHO "Web Applications is not installed at %OPTIM_ROOT%\shared\web. Skipping the uninstall step."
      SET UNINSTALL_SHARED=0
   ) ELSE (
      IF "%MAJOR_UNINSTALL_VERSION%." == "11.3.0.0." (
         @ECHO "Testing if %WEB_BIN%\%WEB_STOP% exists..."
         IF EXIST "%WEB_BIN%\%WEB_STOP%" (
            @ECHO Shutting down Optim Web Applications Server....
            CALL "%WEB_BIN%\%WEB_STOP%" --user %WEB_USER% --password %WEB_PASSWORD%
            SET _RC=!ERRORLEVEL!
            IF NOT "!_RC!." == "0." (
               @ECHO "Optim Web Applications is still running.  Please shutdown the WebSphere Application Server (CE), then try again. RC=!_RC!."
               GOTO :EXIT
            )
            @ECHO The Web Application Server is not running.
         ) ELSE (
            @ECHO "WARNING: The WAS-CE script %WEB_BIN%\%WEB_STOP% not found."
         )
      ) ELSE (
         IF EXIST "%_WEB_BIN%\%_WEB_PGM%" (
            CD %_WEB_BIN%
            CALL "%_WEB_BIN%\%_WEB_PGM%" %_WEB_PARM% %_WEB_STOP%
            SET _RC=!ERRORLEVEL!
            @ECHO %_WEB_PARM% %_WEB_STOP% returned the code %_RC%
            IF NOT "!_RC!." == "0." (
               SET /A "_FINAL_RC=%_RC%"
               GOTO :EXIT
            )
         ) ELSE (
            @ECHO "WARNING: The Web Application script %_WEB_BIN%\%_WEB_PGM% not found."
         )
      )
   )
)

:: The tools subdirectory off the IBM Installation Manager installation directory
:: If IM_ROOT is correct, you should not change this value.
SET "IM_TOOLS_DIR=%IM_ROOT%\tools"

:: The environment variable used by the Installation Manager installer
SET "TMP=%TEMP%"

:: The IATEMPDIR environment variable is only used in 11.3.0.x 
IF "%MAJOR_VERSION%." == "11.3.0.0" (
   REM The environment variable used by the Optim Server feature installer
   SET IATEMPDIR=%TEMP%

   REM Ensure the system temporary directory exist
   IF NOT exist !IATEMPDIR! (
      echo The temporary directory "!IATEMPDIR!" does not exist.
      SET _RC=8
      goto :EXIT
   )
)

:: In 11.3.0.8, the installation log location
SET OPTIM_INSTALL_LOGS=%TEMP%\OptimLogs

:: Ensure the OptimLogs directory exists 
IF NOT EXIST "%OPTIM_INSTALL_LOGS%"               MKDIR "%OPTIM_INSTALL_LOGS%"

:: :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Clear out previous log files
:: %OPTIM_SCRIPTS% contains a trailing "\"
IF EXIST "%OPTIM_ROOT%\IBM_InfoSphere_Optim_InstallLog.log"     DEL "%OPTIM_ROOT%\IBM_InfoSphere_Optim_InstallLog.log"
:: 11.3.0.7
IF EXIST "%OPTIM_ROOT%\Uninstall_IBM Optim\IAOptimInstall.log"  DEL "%OPTIM_ROOT%\Uninstall_IBM Optim\IAOptimInstall.log"
IF EXIST "%OPTIM_ROOT%\Uninstall_IBM Optim\Logs\IBM_InfoSphere_Optim_InstallLog.log" DEL  "%OPTIM_ROOT%\Uninstall_IBM Optim\Logs\IBM_InfoSphere_Optim_InstallLog.log" 
IF EXIST "%TEMP%\IADebugInfoOptim"                              DEL "%TEMP%\IADebugInfoOptim"
:: 11.3.0.8
IF EXIST "%OPTIM_INSTALL_LOGS%\IAOptimInstall.log"              DEL "%OPTIM_INSTALL_LOGS%\IAOptimInstall.log"
IF EXIST "%OPTIM_INSTALL_LOGS%\IADebugInfoOptim"                DEL "%OPTIM_INSTALL_LOGS%\IADebugInfoOptim"
IF EXIST "%TEMP%\jusched.log"                                   DEL "%TEMP%\jusched.log"
IF EXIST "%OPTIM_SCRIPTS%SEA.LOG"                               DEL "%OPTIM_SCRIPTS%SEA.LOG"
IF EXIST "%OPTIM_INSTALL_LOGS%\installDesignerOLHelp_log.xml"   DEL "%OPTIM_INSTALL_LOGS%\installDesignerOLHelp_log.xml"
IF EXIST "%OPTIM_INSTALL_LOGS%\uninstallDesignerOLHelp_log.xml" DEL "%OPTIM_INSTALL_LOGS%\uninstallDesignerOLHelp_log.xml"
IF EXIST "%OPTIM_INSTALL_LOGS%\installRuntime_log.xml"          DEL "%OPTIM_INSTALL_LOGS%\installRuntime_log.xml"
IF EXIST "%OPTIM_INSTALL_LOGS%\uninstallRuntime_log.xml"        DEL "%OPTIM_INSTALL_LOGS%\uninstallRuntime_log.xml"
IF EXIST "%OPTIM_INSTALL_LOGS%\installShared_log.xml"           DEL "%OPTIM_INSTALL_LOGS%\installShared_log.xml"
IF EXIST "%OPTIM_INSTALL_LOGS%\uninstallShared_log.xml"         DEL "%OPTIM_INSTALL_LOGS%\uninstallShared_log.xml"

IF NOT EXIST "%_IM_TOOL%" @ECHO The Installation Manager command line tool %_IM_TOOL% not found.
IF NOT EXIST "%_IM_TOOL%" GOTO :EXIT

:: ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Changed to the Installation Manager tools directory
cd "%IM_TOOLS_DIR%"

:: ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Uninstall Optim Designer and Online Help
if "%UNINSTALL_DESIGNER%" == "1" (
   @ECHO Uninstalling Optim Designer...
   "%_IM_TOOL%" -accessRights %IM_INSTALL_MODE% -input "%OPTIM_SCRIPTS%uninstallDesignerOLHelp.xml" -log "%OPTIM_INSTALL_LOGS%\uninstallDesignerOLHelp_log.xml"
   SET _RC=!ERRORLEVEL!
   @ECHO %_IM_TOOL% [uninstall Optim Designer] exited with the RC %_RC%
)
:: ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Install Optim Designer and Online Help
if "%INSTALL_DESIGNER%" == "1" (
   @ECHO Installing Optim Designer...
   "%_IM_TOOL%" -accessRights %IM_INSTALL_MODE% -input "%OPTIM_SCRIPTS%installDesignerOLHelp.xml" -log "%OPTIM_INSTALL_LOGS%\installDesignerOLHelp_log.xml"  -acceptLicense
   SET _RC=!ERRORLEVEL!
   @ECHO %_IM_TOOL% [uninstall Optim Designer] exited with the RC %_RC%
)

:: ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Uninstall Optim Runtime Services
if "%UNINSTALL_RUNTIME%" == "1" (
   @ECHO Uninstalling Optim Runtime Services...
   "%_IM_TOOL%" -accessRights %IM_INSTALL_MODE% -input "%OPTIM_SCRIPTS%uninstallRuntime.xml" -log "%OPTIM_INSTALL_LOGS%\uninstallRuntime_log.xml"
   SET _RC=!ERRORLEVEL!
   @ECHO %_IM_TOOL% [uninstall Optim Runtime Services] exited with the RC %_RC%
)
:: ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Install Optim Runtime Services
if "%INSTALL_RUNTIME%" == "1" (
   @ECHO Installing Optim Runtime Services...
   "%_IM_TOOL%" -accessRights %IM_INSTALL_MODE% -input "%OPTIM_SCRIPTS%installRuntime.xml" -log "%OPTIM_INSTALL_LOGS%\installRuntime_log.xml"  -acceptLicense
   SET _RC=!ERRORLEVEL!
   @ECHO %_IM_TOOL% [install Optim Runtime Services] exited with the RC %_RC%
   IF NOT EXIST "%OPTIM_ROOT%\rt\bin\RTBUILD.H" (
      SET _RC=99
      @ECHO ERROR *** Optim server feature failed to install ***!
   )
)

:: ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Uninstall Optim Test
if "%UNINSTALL_TEST%" == "1" (
   @ECHO Uninstalling Optim Test...
   "%_IM_TOOL%" -accessRights %IM_INSTALL_MODE% -input "%OPTIM_SCRIPTS%uninstallTest.xml" -log "%OPTIM_INSTALL_LOGS%\uninstallTest_log.xml"
   SET _RC=%ERRORLEVEL%
   @ECHO %_IM_TOOL% [uninstall Optim Test] exited with the RC %_RC%
)
:: ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Install Optim Test
if "%INSTALL_TEST%" == "1" (
   @ECHO Installing Optim Test...
   "%_IM_TOOL%" -accessRights %IM_INSTALL_MODE% -input "%OPTIM_SCRIPTS%installTest.xml" -log "%OPTIM_INSTALL_LOGS%\installTest_log.xml"  -acceptLicense
   SET _RC=%ERRORLEVEL%
   @ECHO %_IM_TOOL% [install Optim Test] exited with the RC %_RC%
)

:: ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Uninstall Optim Shared Components (Optim Web Applications and WAS-CE)
if "%UNINSTALL_SHARED%" == "1" (
   @ECHO Uninstalling Optim Shared Components...
   "%_IM_TOOL%" -accessRights %IM_INSTALL_MODE% -input "%OPTIM_SCRIPTS%%_UNINSTALL_SHARED_XML%" -log "%OPTIM_INSTALL_LOGS%\uninstallShared_log.xml"
   SET _RC=%ERRORLEVEL%
   @ECHO %_IM_TOOL% [uninstall Optim Shared components] exited with the RC %_RC%
)
:: ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Install Optim Shared Components (Optim Web Applications and WAS-CE for 11.3.0.8)
if "%INSTALL_SHARED%" == "1" (
   @ECHO Installing Optim Shared Components...
   "%_IM_TOOL%" -accessRights %IM_INSTALL_MODE% -input "%OPTIM_SCRIPTS%installShared.xml" -log "%OPTIM_INSTALL_LOGS%\installShared_log.xml"  -acceptLicense
   SET _RC=%ERRORLEVEL%
   @ECHO %_IM_TOOL% [install Optim Shared Components] exited with the RC %_RC%
)

:: ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Uninstall Optim Java (Internal Use Only)
if "%UNINSTALL_JAVA%" == "1" (
   @ECHO Uninstalling Optim Java...
   "%_IM_TOOL%" -accessRights %IM_INSTALL_MODE% -input "%OPTIM_SCRIPTS%uninstallSharedJava.xml" -log "%OPTIM_INSTALL_LOGS%\uninstallSharedJava_log.xml"
   SET _RC=%ERRORLEVEL%
   @ECHO %_IM_TOOL% [uninstall Optim Java] exited with the RC %_RC%
)
:: ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Install Optim Java (Internal Use Only)
if "%INSTALL_JAVA%" == "1" (
   @ECHO Installing Optim Java...
   "%_IM_TOOL%" -accessRights %IM_INSTALL_MODE% -input "%OPTIM_SCRIPTS%installSharedJava.xml" -log "%OPTIM_INSTALL_LOGS%\installSharedJava_log.xml"  -acceptLicense
   SET _RC=%ERRORLEVEL%
   @ECHO %_IM_TOOL% [install Optim Java] exited with the RC %_RC%
)

:: ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Display found log files
IF EXIST "%OPTIM_ROOT%\IBM_InfoSphere_Optim_InstallLog.log"      ECHO Found log file: %OPTIM_ROOT%\IBM_InfoSphere_Optim_InstallLog.log
IF EXIST "%OPTIM_ROOT%\Uninstall_IBM Optim\IAOptimInstall.log"   ECHO Found log file: %OPTIM_ROOT%\Uninstall_IBM Optim\IAOptimInstall.log
IF EXIST "%OPTIM_ROOT%\Uninstall_IBM Optim\Logs\IBM_InfoSphere_Optim_InstallLog.log" ECHO Found log file: "%OPTIM_ROOT%\Uninstall_IBM Optim\Logs\IBM_InfoSphere_Optim_InstallLog.log" 
IF EXIST "%TEMP%\IADebugInfoOptim"                               ECHO Found log file: %TEMP%\IADebugInfoOptim
:: 11.3.0.8
IF EXIST "%OPTIM_INSTALL_LOGS%\IAOptimInstall.log"               ECHO Found log file: %OPTIM_INSTALL_LOGS%\IAOptimInstall.log
IF EXIST "%OPTIM_INSTALL_LOGS%\IADebugInfoOptim"                 ECHO Found log file: %OPTIM_INSTALL_LOGS%\IADebugInfoOptim
IF EXIST "%OPTIM_INSTALL_LOGS%\installDesignerOLHelp_log.xml"    ECHO Found log file: %OPTIM_INSTALL_LOGS%\installDesignerOLHelp_log.xml
IF EXIST "%OPTIM_INSTALL_LOGS%\uninstallDesignerOLHelp_log.xml"  ECHO Found log file: %OPTIM_INSTALL_LOGS%\uninstallDesignerOLHelp_log.xml
IF EXIST "%OPTIM_INSTALL_LOGS%\installRuntime_log.xml"           ECHO Found log file: %OPTIM_INSTALL_LOGS%\installRuntime_log.xml
IF EXIST "%OPTIM_INSTALL_LOGS%\uninstallRuntime_log.xml"         ECHO Found log file: %OPTIM_INSTALL_LOGS%\uninstallRuntime_log.xml
IF EXIST "%OPTIM_INSTALL_LOGS%\installShared_log.xml"            ECHO Found log file: %OPTIM_INSTALL_LOGS%\installShared_log.xml
IF EXIST "%OPTIM_INSTALL_LOGS%\uninstallShared_log.xml"          ECHO Found log file: %OPTIM_INSTALL_LOGS%\uninstallShared_log.xml
IF EXIST "%TEMP%\jusched.log"                                    ECHO Found log file: %TEMP%\jusched.log
IF EXIST "%OPTIM_SCRIPTS%SEA.LOG"                                ECHO Found log file: %OPTIM_SCRIPTS%SEA.LOG
GOTO :EXIT

:EXIT
@ECHO Exiting SilentInstall with a return code of %_RC%.
@ECHO -- Exiting SilentInstall.bat --
EXIT /B %_RC%
:: --- End of script ---
