REM #############################################################################
REM installsetenv.bat Sets environment variables for optimutil
REM 
REM   Licensed Materials - Property of IBM
REM   "Restricted Materials of IBM"
REM 
REM   5724-U38, 5724-U39, 5724-U48
REM 
REM    Copyright IBM Corp. 2021 All Rights Reserved
REM 
REM    Copyright 2021 UNICOM Systems, Inc. - All Rights Reserved
REM 
REM   US Government Users Restricted Rights - Use, duplication or
REM   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
REM 
REM  Windows batch script called by optimutil, to set up the environment
REM  for installing Optim in silent or console modes, and updating Optim's
REM  configuration files that specify the JRE and JVM locations in Windows.
REM
REM  Refer to the companion ReadMe.txt file for instructions.
REM 
REM  NOTE: Do not include double quotes (") in the environment variables
REM 
REM ##############################################################################
@echo Setting the default environment for %COMPUTERNAME%

REM Specify the drive and base directory, off of which, the optimutil scripts and Optim will be located
REM Do not include a trailing \ as it will be appended
SET "_HOME=C:"

REM Specify the base installation directory (ending in Optim)
SET "OPTIM_ROOT=%_HOME%\IBM\InfoSphere\Optim"

REM Specify the directory that contains the optimutil and user modified optimsetenv (this file) scripts
REM For ease of use, it is recommended that you also copy your Optim License files to this directory
SET "_ROOT_DIR=%_HOME%\Jenkins"

REM Set the directory of the supporting script files used by optimutil
REM Uncomment only one of the following three lines if you leave the supporting scripts in their original install location
REM SET "_SCRIPTS_DIR=%OPTIM_ROOT%\designer\scripts"
REM SET "_SCRIPTS_DIR=%OPTIM_ROOT%\services\scripts"
REM SET "_SCRIPTS_DIR=%OPTIM_ROOT%\shared\scripts"
REM Comment the following line if you did not copy all of the script files and you are using one of the above
SET "_SCRIPTS_DIR=%_ROOT_DIR%"

REM Specify the value for JRE_HOME (don't include bin)
SET "JRE_HOME=C:\Program Files\AdoptOpenJDK\jdk-8.0.272.10-openj9\jre"
REM Specify the value for JAVA_HOME (don't include jre)
SET "JAVA_HOME=C:\Program Files\AdoptOpenJDK\jdk-8.0.272.10-openj9"
REM The fully qualified path to the JVM
SET "JVM_PATH=C:\Program Files\AdoptOpenJDK\jdk-8.0.272.10-openj9\jre\bin\j9vm\jvm.dll"
REM Specify the location of the Java library RELATIVE to the install directory
REM of Designer or Runtime Services 
REM The JVM must be on the same drive as Optim (A JUNCTION may be used
REM to create a soft link to a JVM if it is on a different drive)
REM For example: mklink /j "D:\Program Files\AdoptOpenJDK" "C:\Program Files\AdoptOpenJDK"
SET "JVM_LOCATION=..\..\..\..\Program Files\AdoptOpenJDK\jdk-8.0.272.10-openj9\jre\bin\j9vm\jvm.dll"

REM =============================================================================
REM When running optimutil to update the JRE or JVM_PATH,
REM you MUST specify the OLD values for JRE_HOME and JVM_PATH here
REM Otherwise, leave these values blank
REM Specify the fully qualified location for the *old* JRE_HOME. (Don't include the jre directory)
SET "JRE_HOME_OLD=C:\Program Files\Semeru\jdk-8.0.302.8-openj9"
REM Specify the fully qualified location to the *old* JVM.
SET "JVM_PATH_OLD=C:\Program Files\Semeru\jdk-8.0.302.8-openj9\jre\bin\j9vm\jvm.dll"
REM NOTE: A value for JVM_LOCATION is not needed.
REM =============================================================================

REM The IBM Installation Manager root directory
SET "IM_ROOT=C:\Program Files\IBM\Installation Manager\eclipse"
REM The location of the Installation Manager command line tool
SET "_IM_TOOL=%IM_ROOT%\tools\imcl.exe"

REM You can download wget from www.gnu.org 
SET "_WGET=C:\GnuWin32\bin\wget.exe"

:: You can download 7-Zip from https://www.7-zip.org
SET "_ZIP=C:\Program Files\7-Zip\7z.exe"

REM Set to true to print debug information from the IA installer when uninstalling 11.3.0.x
SET LAX_DEBUG=false

REM Specify the location of the shared directory
SET "SDP_SHARED=%_HOME%\IBM\Shared"

REM These are can be overwritten by optimutil command line parameters
REM Use 1 to install as an administrator or 0 to install as a non-administrator user
REM depending on how Installation Manager is installed
SET _ADMIN=1
REM The following are only valid with --install
SET _UPDATE=0
SET _KEEP=1
SET _USE_EXISTING=1
SET _DOWNLOAD=0
SET _SOA_QUALIFIER=local
REM Set to the current version without "." (e.g., 11700, 11701, etc.)
SET _SOA_VER=11700

REM Ensure ${_RC} contains the last return code
REM Usually, these should not be changed.
SET _RC=0
SET _URL=
SET _DEBUG=0
SET _MERGE=0
SET "_TMP=C:\Temp"
REM Set to admin or nonAdmin depending on how Installation Manager is installed
IF "%_ADMIN%." == "0." (
   SET IM_INSTALL_MODE=nonAdmin
) ELSE (
   SET IM_INSTALL_MODE=admin
)
REM These are managed by the optimutil script 
REM UNINSTALL_RUNTIME=1
REM INSTALL_RUNTIME=1
REM UNINSTALL_SHARED=1
REM INSTALL_SHARED=1

REM Internal Use Only
SET UNINSTALL_JAVA=0
SET INSTALL_JAVA=0
SET UNINSTALL_TEST=0
SET INSTALL_TEST=0
SET _INTERNAL=0
REM Specify false. A value of true is for internal use only
SET USE_OPTIM_JAVA=false

REM Specify information to shutdown the WAS-CE Application Server (11.3.0.8 Only)
SET WEB_USER=system
SET WEB_PASSWORD=manager

REM (Windows Only) Set to true to create desktop shortcuts
SET CREATE_DESKTOP_SHORTCUTS=true
REM (Windows Only) Set to true to create Optim file associations (requires write access to the Windows Registry)
SET CREATE_OPTIM_FILE_ASSOCIATIONS=true
REM Set to true to populate the OptimConfigClient.pst file with Optim entries from the Windows Registry 
REM WARNING: This action will wipe out any existing entries to the existing OptimConfigClient.pst 
REM (requires read access to the Windows Registry)
REM You can also select the Optim Config Population start menu option to run this step later 
SET POPULATE_OPTIM_CONFIG=false

REM Set to true to delete the OptimConfigClient.pst file at unintall times. 
REM WARNING: Only set to true if do not plan on installing another instance of 
REM        Optim on this computer
SET DELETE_OPTIM_CONFIG_FILES=false
    
REM (Windows Only) Set to true to delete the Optim entries in the Windows registry. 
REM WARNING: Only set to true if do not plan on installing another instance of 
REM Optim on this computer
SET DELETE_OPTIM_WINDOWS_REGISTRY_ENTRIES=false

REM Specify the location of the OptimConfigClient/Server.pst files installed by Runtime Services
SET "OPTIM_CONFIG_CLIENT_LOCATION=%OPTIM_ROOT%\rt\OptimConfigClient.pst"
REM Specify the location of the OptimConfigServer.pst file installed by Runtime Services
SET "OPTIM_CONFIG_SERVER_LOCATION=%OPTIM_ROOT%\rt\OptimConfigServer.pst"

REM Set true if you have one or more Optim Permanent License files
SET OPTIM_PERMANENT_LICENSE=true
REM If OPTIM_PERMANENT_LICENSE is true, set to true if you have an Optim Data Grown Permanent license
SET OPTIM_PERMANENT_DG_LICENSE=true
REM If OPTIM_PERMANENT_DG_LICENSE is true, set to the directory (not file name) of the Optim Data Grown Permanent license file
SET "OPTIM_PERMANENT_DG_LICENSE_DIRECTORY=%_ROOT_DIR%"
REM If OPTIM_PERMANENT_LICENSE is true, set to true if you have an Optim Test Data Management Permanent license
SET OPTIM_PERMANENT_TDM_LICENSE=true
REM If OPTIM_PERMANENT_TDM_LICENSE is true, set to the directory (not file name) of the Optim Test Data Management Permanent license file
SET "OPTIM_PERMANENT_TDM_LICENSE_DIRECTORY=%_ROOT_DIR%"
REM If OPTIM_PERMANENT_LICENSE is true, set to true if you have an Optim Data Privacy Permanent license
SET OPTIM_PERMANENT_DP_LICENSE=true
REM If OPTIM_PERMANENT_DP_LICENSE is true, set to the directory (not file name) of the Optim Data Privacy Permanent license file
SET "OPTIM_PERMANENT_DP_LICENSE_DIRECTORY=%_ROOT_DIR%"

REM Deprecated in 11.7. To Install ODM specify: ODM_FEATURE_NAME=,nex.optim.odm
SET "ODM_FEATURE_NAME= "
REM ODM_PERMANENT_LICENSE and ODM_TRIAL_LICENSE must not both be true
SET ODM_PERMANENT_LICENSE=false
SET ODM_TRIAL_LICENSE=false
SET "ODM_PERMANENT_LICENSE_PATH= "

REM Set to the current major version being installed (e.g., 11.3.0.0 etc.)
SET MAJOR_VERSION=11.7.0.0
REM Set to the major version being uninstalled (e.g., 11.3.0.0, 11.7.0.0)
SET "MAJOR_UNINSTALL_VERSION=11.3.0.0"
REM Set to the current version without "." (e.g., 11308, 11309, 11700, etc.)
SET CURRENT_VERSION=!_SOA_VER!

REM Specify the location of the base Launch pad repository
REM Note: it must end with disk1
REM SET OPTIM_LAUNCHPAD=%_SCRIPTS_DIR%\launchpad\repo\disk1

REM Set to the location of the expanded Designer install repository
SET "OPTIM_FIXPACK_DESIGNER=%_SCRIPTS_DIR%\designer"

REM Set to the location of the expanded Runtime Services install repository
SET "OPTIM_FIXPACK_RUNTIME=%_SCRIPTS_DIR%\runtime"

REM Set to the location of the expanded Web Applications install repository 
SET "OPTIM_FIXPACK_WEB=%_SCRIPTS_DIR%\shared\web"

REM Internal use only
SET "OPTIM_FIXPACK_JAVA=%_SCRIPTS_DIR%\shared\java"
SET "OPTIM_FIXPACK_TEST=%_SCRIPTS_DIR%\test"

REM Set the target OS. For
REM Windows [any bitness] specify win32
SET TARGET_OS=win32
REM Set the target windowing system. For
REM Windows [any bitness] specify win32
SET TARGET_WS=win32
REM Set application architecture. For
REM Windows: For 11.7 specify x86_64 for 64 bit.
SET TARGET_ARCH=x86_64
