@ECHO OFF
:: :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: optimutil.cmd
::
::    Licensed Materials - Property of IBM
::    "Restricted Materials of IBM"
::
::    5724-U38, 5724-U39, 5724-U48
::
::     Copyright IBM Corp. 2021 All Rights Reserved
::
::     Copyright 2021 UNICOM Systems, Inc. - All Rights Reserved
::
::    US Government Users Restricted Rights - Use, duplication or
::    disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
::
:: Windows command file that can be used to:
::    Install or uninstall an Optim component in silent mode
::    Start Installation Manager in console mode
::    Update the JRE and JVM location for a currently installed Optim component
::    Perform a silent install or update of the JRE/JVM in an automated way
::
:: Supported Optim components:
:: Optim Designer, Optim Runtime Services, and Optim Web Applications
:: 
:: Refer to the ReadMe.txt file for instructions on using this batch file.
::
:: Run this batch file with no parameters for command syntax
:: ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
SETLOCAL EnableDelayedExpansion
SETLOCAL EnableExtensions

GOTO :START

REM ##############################################################################
REM EXIT_CODE   Display and exit an exit code
REM ##############################################################################
:EXIT_CODE
   IF NOT "%_RC%" == "0" (
      @ECHO Use --help to display the syntax.
   )
   @ECHO Complete. RC=%_RC%
   EXIT /B %_RC%

REM ##############################################################################
REM CONSOLE_INSTALL   Run Installation Manager in Console Mode
REM ##############################################################################
:CONSOLE_INSTALL
   IF "%_SOA_COMPONENT%." == "." (
      SET "_REPO_DIR="
      SET "_IM_PACKAGE="
   ) ELSE IF "%_SOA_COMPONENT%." == "designer." (
      SET "_REPO_DIR=%OPTIM_FIXPACK_DESIGNER%"
      SET _IM_PACKAGE=com.ibm.nex.designer
   ) ELSE IF "%_SOA_COMPONENT%." == "runtime." (
      SET "_REPO_DIR=%OPTIM_FIXPACK_RUNTIME%"
      SET _IM_PACKAGE=com.ibm.nex.proxy
   ) ELSE IF "%_SOA_COMPONENT%." == "web." (
      SET "_REPO_DIR=%OPTIM_FIXPACK_WEB%"
      SET _IM_PACKAGE=com.ibm.nex.console
   ) ELSE (
      @ECHO --com[omponent] must be designer, runtime, or web.
      SET _RC=4
      GOTO :EXIT_CODE
   )
   IF "%_SOA_COMPONENT%." == "." (
      CALL "%_IM_TOOL%" -consoleMode -accessRights %IM_INSTALL_MODE%
      SET _RC=%ERRORLEVEL%
   ) ELSE (
      CALL "%_IM_TOOL%" -consoleMode -accessRights %IM_INSTALL_MODE% -repositories !_REPO_DIR! install !_IM_PACKAGE!
      SET _RC=%ERRORLEVEL%
   )
   @ECHO " "
   @ECHO The Installation Manager Console tool completed. RC=%_RC%
   EXIT /B %_RC%

REM ##############################################################################
REM :DISPLAY_COMMAND  Display the current command
REM ##############################################################################
:DISPLAY_COMMAND
   @ECHO Running the following command:
   @ECHO "%_THIS_SCRIPT% --%_ACTION%"
   @ECHO "   --roo %OPTIM_ROOT% --com %_SOA_COMPONENT%"
   IF "%_ACTION%" == "install" (
      @ECHO "   --ver %_SOA_VER% --unv %MAJOR_UNINSTALL_VERSION% --qua %_SOA_QUALIFIER%"
      @ECHO "   --kee %_KEEP% --del %_DELETE% --upd %_UPDATE% --use %_USE_EXISTING% --dow %_DOWNLOAD%"
   ) ELSE IF "%_ACTION%" == "java" (
      @ECHO "   --jre %JRE_HOME% --oje %JRE_HOME_OLD%"
      @ECHO "   --jvm %JVM_PATH% --ojm %JVM_PATH_OLD%"
   )
   GOTO :EOF

REM ##############################################################################
REM :DISPLAY_STATUS  Display the installed Optim offerings
REM ##############################################################################
:DISPLAY_STATUS
   @ECHO Installed packages:
   CALL "%_IM_TOOL%" -s listinstalledpackages  -accessRights %IM_INSTALL_MODE% 
   SET _RC=%ERRORLEVEL%
   IF EXIST "%OPTIM_ROOT%\rt\bin\version.txt"   type "%OPTIM_ROOT%\rt\bin\version.txt"

   GOTO :EXIT_CODE

REM ##############################################################################
REM DISPLAY_SYNTAX   Displays the command syntax and exits
REM ##############################################################################
:DISPLAY_SYNTAX
   @ECHO Syntax:
   @ECHO  %_THIS_SCRIPT% [option] command [--com COMPONENT [parameters...]]
   @ECHO  Where option is one or more of the following:
   @ECHO    --adm [1=run as an administrator, 0=run as a user]
   @ECHO    --roo [OPTIM_ROOT=Optim root directory] Surround directory value with double quotes if it contains embedded spaces
   @ECHO  Where command is one of the following:
   @ECHO    --help Display this help, then exit
   @ECHO    --install Install an Optim component in silent mode
   @ECHO    --console Start Installation Manager in console mode to install Optim
   @ECHO    --java Update the JRE_HOME and JVM used by Optim
   @ECHO    --status Display the status of installed components, then exit
   @ECHO  For --install and --java, you must specify an Optim component [Optional for --console]:
   @ECHO    --com [COMPONENT=designer, runtime or web]
   @ECHO    --jre [JRE_HOME=value for JRE_HOME] Surround value with double quotes if it contains embedded spaces
   @ECHO    --jvm [JVM_PATH=path to jvm.dll]  Surround path with double quotes if it contains embedded spaces
   @ECHO  Additional parameters for --java:
   @ECHO    --oje [JRE_HOME=old value for JRE_HOME]  No embedded spaces permitted if passed as a parameter
   @ECHO    --ojm [JVM_PATH=old path to jvm.dll]  No embedded spaces permitted if passed as a parameter
   @ECHO  Additional parameters for --install in silent mode only:
   @ECHO    --del [0=uninstall, then install, 1=uninstall only]
   @ECHO    --kee [0=don't keep, 1=keep] downloaded artifact
   @ECHO    --qua [QUALIFIER='local' or the fully qualified timestamp]
   @ECHO    --unv [UNinstallVersion=the 4 position major version with 3 decimal points (i.e., 11.3.0.0)]
   @ECHO    --upd [0=uninstall/install or 1=update]
   @ECHO    --use [0=new repository, 1=existing repository]
   @ECHO    --ver [VER=the 4 position version with no decimal points (i.e., 11700)]
   @ECHO  Advanced parameters for --install:
   @ECHO    --dow [0=don't download, 1=download] the installer from a local network drive
   @ECHO    --url [URL local network drive]
   @ECHO Where:
   @ECHO  QUALIFIER A fully qualified timestamp YYYMMDD_HHSS for a tar.gz file;
   @ECHO            local for a local repository; or remote to download
   @ECHO            the last created tar.gz file [internal use only]
   @ECHO NOTE: Refer to the companion ReadMe.txt file for instructions.
   GOTO :EXIT_CODE

REM ##############################################################################
REM UPDATE_FILE   Update a file
REM ##############################################################################
:UPDATE_FILE

   IF "%_SEARCH%" == "." (
      @ECHO ERROR A search argument required.
      SET _RC=99
      GOTO :EXIT_CODE
   )
   IF "%_REPLACE%" == "." (
      @ECHO ERROR A replace argument required.
      SET _RC=99
      GOTO :EXIT_CODE
   )
   IF "%_FILE%" == "." (
      @ECHO ERROR A file argument required.
      SET _RC=99
      GOTO :EXIT_CODE
   )
   @ECHO Updating file %_FILE% ...
   @ECHO   Replace %_SEARCH%
   @ECHO   with    %_REPLACE%
   
   SETLOCAL enableextensions disabledelayedexpansion
   FOR /f "delims=" %%i in ('type "%_FILE%" ^& break ^> "%_FILE%" ') do (
      SET "_LINE=%%i"
      SETLOCAL enabledelayedexpansion
      >>"%_FILE%" echo(!_LINE:%_SEARCH%=%_REPLACE%!
      ENDLOCAL
   )
   GOTO :EOF

REM ##############################################################################
REM UPDATE_ECLIPSE_INI   Update an eclipse.ini file
REM ##############################################################################
:UPDATE_ECLIPSE_INI
   REM Always update the JVM before JRE_HOME as the JRE_HOME may be a substring of the JVM
   SET "_SEARCH=%JVM_PATH_OLD%"
   SET "_REPLACE=%JVM_PATH%"
   SET "_FILE=%_ECLIPSE_INI%"
   CALL :UPDATE_FILE
   GOTO :EOF

REM ##############################################################################
REM UPDATE_OPTIM_PROPERTIES   Update the optim.properties file
REM ##############################################################################
:UPDATE_OPTIM_PROPERTIES
   REM Always update the JVM before JRE_HOME as the JRE_HOME may be a substring of the JVM
   SET "_SEARCH=%JVM_PATH_OLD%"
   SET "_REPLACE=%JVM_PATH%"
   SET "_FILE=%_OPTIM_PROPERTIES%"
   CALL :UPDATE_FILE
   SET "_SEARCH=%JRE_HOME_OLD%"
   SET "_REPLACE=%JRE_HOME%"
   SET "_FILE=%_OPTIM_PROPERTIES%"
   CALL :UPDATE_FILE
   GOTO :EOF

REM ##############################################################################
REM UPDATE_OPTIM_CONFIG_PST   Update the OprimConfig*.pst files
REM ##############################################################################
:UPDATE_OPTIM_CONFIG_PST
   REM There are 4 .pst files to update 2 of which are optional so may not exist
   SET "PSTFILES=%_OPTIM_CONFIG_CLIENT_PST% %_OPTIM_CONFIG_CLIENT_PRESERVE_PST% %_OPTIM_CONFIG_SERVER_PST% %_OPTIM_CONFIG_SERVER_PRESERVE_PST%"
   for %%f in (%PSTFILES%) do (
      IF EXIST %%f (
         SET "_SEARCH=%JVM_PATH_OLD%"
         SET "_REPLACE=%JVM_PATH%"
         SET "_FILE=%%f"
         CALL :UPDATE_FILE
         SET "_SEARCH=%JRE_HOME_OLD%"
         SET "_REPLACE=%JRE_HOME%"
         CALL :UPDATE_FILE
      )
   )
   GOTO :EOF

REM ##############################################################################
REM UPDATE_RTSETJVM   Update the rtsetjvm.cmd file
REM ##############################################################################
:UPDATE_RTSETJVM
   REM Always update the JVM before JRE_HOME as the JRE_HOME may be a substring of the JVM
   SET "_SEARCH=%JVM_PATH_OLD%"
   SET "_REPLACE=%JVM_PATH%"
   SET "_FILE=%_RTSETJVM%"
   CALL :UPDATE_FILE
   SET "_SEARCH=%JRE_HOME_OLD%"
   SET "_REPLACE=%JRE_HOME%"
   SET "_FILE=%_RTSETJVM%"
   CALL :UPDATE_FILE
   GOTO :EOF

REM ##############################################################################
REM UPDATE_SET_JRE   Update the set_jre.cmd file
REM ##############################################################################
:UPDATE_SET_JRE
   REM Always update the JVM before JRE_HOME as the JRE_HOME may be a substring of the JVM
   SET "_SEARCH=%JRE_HOME_OLD%"
   SET "_REPLACE=%JRE_HOME%"
   SET "_FILE=%_SET_JRE%"
   CALL :UPDATE_FILE
   GOTO :EOF

REM ##############################################################################
REM UPDATE_JAVA   Update the JRE_HOME and JVM_PATH settings
REM ##############################################################################
:UPDATE_JAVA
   :: Clear out the eclipse.ini location for either Designer or Runtime
   SET "_ECLIPSE_INI="
   :: Clear out the optim.properties location for Runtime
   SET "_OPTIM_PROPERTIES="
   :: Clear out the OptimConfigClient.pst location for Runtime
   SET "_OPTIM_CONFIG_CLIENT_PST="
   :: Clear out the OptimConfigServer.pst location for Runtime
   SET "_OPTIM_CONFIG_SERVER_PST="
   :: Clear out the OptimConfigClientPreserve.pst location for Runtime
   SET "_OPTIM_CONFIG_CLIENT_PRESERVE_PST="
   :: Clear out the OptimConfigServerPreserve.pst location for Runtime
   SET "_OPTIM_CONFIG_SERVER_PRESERVE_PST="
   :: Clear out the rtsetjvm.bat location for Runtime
   SET "_RTSETJVM="
   :: Clear out the set_jre.cmd location for Web Applications
   SET "_SET_JRE="

   IF "%_SOA_COMPONENT%" == "designer" (
      :: Set the eclipse.ini for Designer
      SET "_ECLIPSE_INI=%OPTIM_ROOT%\designer\eclipse.ini"
      @ECHO Validating "!_ECLIPSE_INI!...
      IF NOT EXIST "!_ECLIPSE_INI!" (
         @ECHO ERROR: The file "!_ECLIPSE_INI!", used by Optim Designer, can not be found.
         SET _RC=2
         GOTO :EXIT_CODE 
      )
   ) ELSE IF "%_SOA_COMPONENT%" == "runtime" (
      :: Set the eclipse.ini for Runtime
      SET "_ECLIPSE_INI=%OPTIM_ROOT%\services\eclipse.ini"
      :: Set the optim.properties for Runtime
      SET "_OPTIM_PROPERTIES=%OPTIM_ROOT%\rt\optim.properties"
      :: Set the OptimConfigClient.pst for Runtime
      SET "_OPTIM_CONFIG_CLIENT_PST=%OPTIM_ROOT%\rt\OptimConfigClient.pst"
      :: Set the OptimConfigServer.pst for Runtime
      SET "_OPTIM_CONFIG_SERVER_PST=%OPTIM_ROOT%\rt\OptimConfigServer.pst"
      :: Set the OptimConfigClientPreserve.pst for Runtime
      SET "_OPTIM_CONFIG_CLIENT_PRESERVE_PST=%OPTIM_ROOT%\rt\OptimConfigClientPreserve.pst"
      :: Set the OptimConfigServerPreserve.pst for Runtime
      SET "_OPTIM_CONFIG_SERVER_PRESERVE_PST=%OPTIM_ROOT%\rt\OptimConfigServerPreserve.pst"
      :: Set the rtsetjvm for Runtime
      SET "_RTSETJVM=%OPTIM_ROOT%\rt\rtsetjvm.bat"  
	  SET "MandatoryFiles=!_ECLIPSE_INI! !_OPTIM_PROPERTIES! !_OPTIM_CONFIG_CLIENT_PST! !_OPTIM_CONFIG_SERVER_PST! !_RTSETJVM!"
	  SET "OptionalFiles=!_OPTIM_CONFIG_CLIENT_PRESERVE_PST! !_OPTIM_CONFIG_SERVER_PRESERVE_PST!"
	  
	  for %%f in (!MandatoryFiles!) do (
	    @ECHO Validating %%f
		IF NOT EXIST "%%f" (
           @ECHO ERROR: The file "%%f", used by the Optim Runtime Services, can not be found.
           SET _RC=2
		)
	  )
	  if "!_RC!" == "2" (
	     GOTO :EXIT_CODE
      )
	  for %%f in (!OptionalFiles!) do (
	    @ECHO Validating %%f
		IF NOT EXIST "%%f" (
           @ECHO INFO: The file "%%f", optionally used by Optim Runtime Services, can not be found and will not be processed.
		)
	  )	  
   ) ELSE IF "%_SOA_COMPONENT%" == "test" (
      :: Set the eclipse.ini for testing
      SET "_ECLIPSE_INI=%OPTIM_ROOT%\test\eclipse.ini"
   
      @ECHO Validating "!_ECLIPSE_INI! ...
      IF NOT EXIST "!_ECLIPSE_INI!" (
         @ECHO ERROR: The file "!_ECLIPSE_INI!", used for Optim Testing, can not be found.
         SET _RC=2
         GOTO :EXIT_CODE 
      )
   ) ELSE IF "%_SOA_COMPONENT%" == "web" (
      :: Set the set_jre for Web Applications
      SET "_SET_JRE=%OPTIM_ROOT%\shared\web\setup\set_jre.cmd"
   
      @ECHO Validating "!_SET_JRE!" ...
      IF NOT EXIST "!_SET_JRE!" (
         @ECHO ERROR: The batch file "!_SET_JRE!", used by the Optim Web Applications, can not be found.
         SET _RC=2
         GOTO :EXIT_CODE 
      )
   ) ELSE (
      @ECHO ERROR: The component name %_SOA_COMPONENT% is not designer, runtime, or web.
      SET _RC=11
      GOTO :EXIT_CODE
   )  
   
   CALL :DISPLAY_COMMAND
   
   :START_UPDATE
   
   IF "%_SOA_COMPONENT%" == "designer" (
      CALL :UPDATE_ECLIPSE_INI
   ) ELSE IF "%_SOA_COMPONENT%" == "runtime" (
      CALL :UPDATE_ECLIPSE_INI
      CALL :UPDATE_OPTIM_PROPERTIES
      CALL :UPDATE_OPTIM_CONFIG_PST
      CALL :UPDATE_RTSETJVM
   ) ELSE IF "%_SOA_COMPONENT%" == "test" (
      CALL :UPDATE_ECLIPSE_INI
   ) ELSE IF "%_SOA_COMPONENT%" == "web" (
      CALL :UPDATE_SET_JRE
   ) ELSE (
      @ECHO The component name %_SOA_COMPONENT% is not designer, runtime, or web.
      SET _RC=11
      GOTO :EXIT_CODE
   )  
   GOTO :EXIT_CODE

REM ##############################################################################
REM VALIDATE_ENVIRONMENT   Validate the environment
REM ##############################################################################
:VALIDATE_ENVIRONMENT
   @ECHO Validating the environment ...
   IF "%_SOA_COMPONENT%." == "." (
      @ECHO ERROR: The parameter --com[ponent] and a component name of designer, runtime or web are required.
      SET _RC=4
      GOTO :EXIT_CODE
   )
   IF "%_SOA_COMPONENT%." == "designer." (
      @ECHO . >NUL 2>&1
   ) ELSE IF "%_SOA_COMPONENT%." == "runtime." (
      @ECHO . >NUL 2>&1
   ) ELSE IF "%_SOA_COMPONENT%." == "test." (
     REM Component test is for internal use only
      @ECHO . >NUL 2>&1
   ) ELSE IF "%_SOA_COMPONENT%." == "web." (
      @ECHO . >NUL 2>&1
   ) ELSE (
      @ECHO --com[ponent] must be designer, runtime or web.
      SET _RC=4
      GOTO :EXIT_CODE
   )
   IF "%_SOA_VER%" == "" (
      @ECHO ERROR: A four digit Optim version, _SOA_VER, is required
      @ECHO either as a parameter --ver [OPTIM_VERION] or
      @ECHO as a variable in the file %_DIR%\optimsetenv.bat.
      SET _RC=5
      GOTO :EXIT_CODE
   )
   
   IF "%_HOME%." == "." (
      @ECHO ERROR: The environment variable _HOME must be specified
      @ECHO as a variable in the file %_DIR%optimsetenv.bat.
      SET _RC=8
      GOTO :EXIT_CODE
   )
   IF NOT EXIST "%_HOME%" (
      @ECHO ERROR: The home directory %_HOME%, as defined by _HOME, does not exist.
      SET _RC=8
      GOTO :EXIT_CODE
   )

   IF "%OPTIM_ROOT%." == "." (
      @ECHO ERROR: The environment variable OPTIM_ROOT must be specified
      @ECHO either as a parameter --roo [optim_root] or
      @ECHO as a variable in the file %_DIR%optimsetenv.bat.
      SET _RC=8
      GOTO :EXIT_CODE
   )
   IF NOT EXIST "%OPTIM_ROOT%" (
      IF "%_ACTION%" == "java" (
         @ECHO ERROR: The Optim Root directory %OPTIM_ROOT%, as defined by OPTIM_ROOT, does not exist.
         SET _RC=7
         GOTO :EXIT_CODE
      ) ELSE (
         @ECHO WARNING: The Optim Root directory %OPTIM_ROOT%, as defined by OPTIM_ROOT, does not exist.
      )
   )

   IF '%_ROOT_DIR%' == '' (
      @ECHO ERROR: _ROOT_DIR must be defined
      @ECHO as a variable in the file %_DIR%optimsetenv.bat.
      SET _RC=8
      GOTO :EXIT_CODE
   )
   IF NOT EXIST "%_ROOT_DIR%" (
      @ECHO ERROR: The root directory %_ROOT_DIR%, as defined by _ROOT_DIR, does not exist.
      @ECHO It should be set to the directory of this batch file.
      SET _RC=8
      GOTO :EXIT_CODE
   )
   IF NOT EXIST "%_ROOT_DIR%\optimutil.cmd" (
      @ECHO ERROR: The root directory %_ROOT_DIR%, as defined by _ROOT_DIR, does not contain the optimutil file.
      @ECHO It should be set to the directory of this batch file.
      SET _RC=8
      GOTO :EXIT_CODE
   )
   IF "%_SCRIPTS_DIR%." == "." (
      @ECHO ERROR: _SCRIPTS_DIR must be specified
      @ECHO as a variable in the file %_DIR%optimsetenv.bat.
      SET _RC=8
      GOTO :EXIT_CODE
   )
   IF NOT EXIST "%_SCRIPTS_DIR%" (
      @ECHO ERROR: The scripts directory %_SCRIPTS_DIR%, as defined by _SCRIPTS_DIR, does not exist.
      SET _RC=8
      GOTO :EXIT_CODE
   )
   IF NOT EXIST "%_SCRIPTS_DIR%\SilentInstall.bat" (
      @ECHO ERROR: The scripts directory %_SCRIPTS_DIR%, as defined by _SCRIPTS_DIR, must contain the SilentInstall.bat script.
      @ECHO It should be set to the directory of the companion batch and XML files.
      SET _RC=8
      GOTO :EXIT_CODE
   )

   IF "%JRE_HOME%." == "." (
      @ECHO ERROR: The environment variable JRE_HOME must be specified
      @ECHO either as a parameter --jre [JRE_HOME] or
      @ECHO as a variable in the file %_DIR%optimsetenv.bat.
      SET _RC=7
      GOTO :EXIT_CODE
   )
   IF NOT EXIST "%JRE_HOME%" (
      @ECHO ERROR: The JRE_HOME directory %JRE_HOME%, does not exist.
      SET _RC=7
      GOTO :EXIT_CODE
   )
   IF NOT EXIST "%JRE_HOME%\bin\java.exe" (
      @ECHO ERROR: The java executable file %JRE_HOME%\bin\java.exe, does not exist.
      @ECHO Ensure that the variable JRE_HOME does not include the jre directory.
      SET _RC=7
      GOTO :EXIT_CODE
   )
   IF "%JVM_PATH%." == "." (
      @ECHO ERROR: The environment variable JVM_PATH must be specified
      @ECHO either as a parameter --jvm [JVM_PATH] or
      @ECHO as a variable in the file %_DIR%optimsetenv.bat.
      SET _RC=11
      GOTO :EXIT_CODE
   )
   IF NOT EXIST "%JVM_PATH%" (
      @ECHO ERROR: The file %JVM_PATH%, as defined by JVM_PATH, does not exist.
      SET _RC=12
      GOTO :EXIT_CODE
   )
   ECHO.%JVM_PATH% | FIND /I "jvm.dll">nul
   IF errorlevel 1 (
      @ECHO ERROR: The JVM path %JVM_PATH%, as defined by JVM_PATH, must point to the file jvm.dll.
      SET _RC=12
      GOTO :EXIT_CODE
   )
   
   IF "%_ACTION%" == "java" (
      REM The old JRE may have been uninstalled, so only validate the variables exist
      IF "%JRE_HOME_OLD%." == "." (
         @ECHO ERROR: The environment variable JRE_HOME_OLD must be specified
         @ECHO either as a parameter --oje [JRE_HOME_OLD] or
         @ECHO as a variable in the file %_DIR%optimsetenv.bat.
         SET _RC=10
         GOTO :EXIT_CODE
      )
      IF "%JVM_PATH_OLD%." == "." (
         @ECHO ERROR: The environment variable JVM_PATH_OLD must be specified
         @ECHO either as a parameter --ojm [JVM_PATH_OLD] or
         @ECHO as a variable in the file %_DIR%optimsetenv.bat.
         SET _RC=12
         GOTO :EXIT_CODE
      )
      ECHO.%JVM_PATH_OLD% | FIND /I "jvm.dll">nul
      IF errorlevel 1 (
         @ECHO ERROR: The old JVM path %JVM_PATH_OLD%, as defined by JVM_PATH_OLD, must point to the old jvm.dll file.
         SET _RC=12
         GOTO :EXIT_CODE
      )
      IF "%JRE_HOME_OLD%" == "%JRE_HOME%" (
         @ECHO WARNING: The values for the environment variables JRE_HOME and JRE_HOME_OLD are identical.
         SET _RC=13
      )
      IF "%JVM_PATH_OLD%" == "%JVM_PATH%" (
         @ECHO WARNING: The values for the environment variables JVM_PATH and JVM_PATH_OLD are identical.
         SET _RC=13
      )
   )
   IF "%_ACTION%" == "install" (
      IF "%_DOWNLOAD%." == "1." (
         IF NOT EXIST "%_WGET%" (
            @ECHO Cannot find %_WGET%
            SET _RC=6
            GOTO :EXIT_CODE
         )
         IF NOT EXIST "%_ZIP%" (
            @ECHO Cannot find %_ZIP%
            SET _RC=6
            GOTO :EXIT_CODE
         )
         IF "%_URL%" == "" (
            @ECHO The parameter --url and a value are required.
            SET _RC=3
            GOTO :EXIT_CODE
         )
         IF "%_USE_EXISTING%." == "1." (
            @ECHO The parameter --dow[nload] 1 is not permitted with --use[ existing] 1.
            SET _RC=10
            GOTO :EXIT_CODE
         )
      )
   )
   GOTO :EOF

REM ##############################################################################
REM VALIDATE_IM_ENVIRONMENT   Validate the Installation Manager environment
REM ##############################################################################
:VALIDATE_IM_ENVIRONMENT
   @ECHO Validating the Installation Manager environment ...
   IF "%_ADMIN%." == "." (
      @ECHO ERROR: The environment variable _ADMIN, which defines how Installation Manager was installed, must be to set
      @ECHO either as a parameter --adm [1=administrator or 0=user] or 
      @ECHO as a variable in the file %_DIR%\optimsetenv.bat.
      SET _RC=20
      GOTO :EXIT_CODE
   )
   net session > NUL 2>&1
   IF %ERRORLEVEL% EQU 0 (
      IF "%_ADMIN%." == "0." (
         @ECHO ERROR: You are attempting to run Installation Manager as a user but the command prompt has administrator privileges. 
         SET _RC=9
         GOTO :EXIT_CODE
      )
   ) ELSE (
      IF "%_ADMIN%." == "1." (
         @ECHO ERROR: You are attempting to run Installation Manager as an administrator user but the command prompt does not have administrator privileges. 
         SET _RC=9
         GOTO :EXIT_CODE
      )
   )
   IF "%IM_ROOT%." == "." (
      @ECHO ERROR: The environment variable IM_ROOT must be set to the IBM Installation Manager eclipse directory
      @ECHO in the file %_DIR%\optimsetenv.bat.
      SET _RC=20
      GOTO :EXIT_CODE
   )
   IF NOT EXIST "%IM_ROOT%" (
      @ECHO "The IBM Installation Manager eclipse directory %IM_ROOT%, as defined by IM_ROOT, not found."
      SET _RC=9
      GOTO :EXIT_CODE
   )
   IF "%_IM_TOOL%." == "." (
      @ECHO ERROR: The environment variable _IM_TOOL must be to the IBM Installation Manager imcl program in the tools directory
      @ECHO in the file %_DIR%\optimsetenv.bat.
      SET _RC=20
      GOTO :EXIT_CODE
   )
   IF NOT EXIST "%_IM_TOOL%" (
      @ECHO "The IBM Installation Manager tools program %_IM_TOOL%, as defined by _IM_TOOL, not found."
      SET _RC=20
      GOTO :EXIT_CODE
   ) 
   GOTO :EOF

REM ##############################################################################
REM START   Start of processing
REM ##############################################################################
:START

REM Reset all variables 
SET "_FILE_LIST=_ACTION _ADMIN _COMPONENT_DIR _COPY_FILE_LIST _DEBUG _DELETE _DIR _DOWNLOAD _FART _IM_TOOL _INSTALL _INSTALLER _INTERNAL _JENKINS_DIR _KEEP _LINE _MERGE _OFFERING _PARM_VALUE_BOOL _PERFORM _PROJECT_DIR _PROJECT_FILE _PROJECT_ROOT _RC _REPO _ROOT_DIR _SCRIPTS_DIR _SHARED_DIR _SOA_COMPONENT _SOA_QUALIFIER _SOA_VER _TAR _TAR_GZ _THIS_SCRIPT _UNINSTALL_SHARED_XML _UPDATE _URL _USE_EXISTING _WGET _ZIP JRE_HOME JAVA_HOME JVM_PATH JVM_LOCATION JRE_HOME_OLD JVM_PATH_OLD"

FOR %%F IN (%_FILE_LIST%) DO (
   SET "%%F="
)

REM Get Script directory if it not already set
IF "%_DIR%." == "." SET _DIR=%~dp0

REM Save the name of this script as it will be destroyed later
SET "_THIS_SCRIPT=%~n0%~x0"

REM Does a file exist which sets up the defaults
IF EXIST "%_DIR%optimsetenv.bat" (
   @ECHO Loading local environment variables from %_DIR%optimsetenv.bat.
   CALL "%_DIR%optimsetenv.bat"
) else (
   @ECHO ERROR: You must define an environment variables file named %_DIR%optimsetenv.bat.
   @ECHO A template file is provided in the SCRIPTS directory.
   SET _RC=9
   GOTO :EXIT_CODE
)

@ECHO COMPUTERNAME:       %COMPUTERNAME%
:: You can download wget from www.gnu.org
IF "%_WGET%." == "."          SET "_WGET=C:\GnuWin32\bin\wget.exe"
:: You can download Jenkins from https://jenkins.io, or use you own automation server
IF "%_ROOT_DIR%." == "."      SET "_ROOT_DIR=C:\Jenkins"
IF "%_SCRIPTS_DIR%." == "."   SET "_SCRIPTS_DIR=%_ROOT_DIR%\scripts"
:: You can download 7-Zip from https://www.7-zip.org
IF "%_ZIP%." == "."           SET "_ZIP=C:\Program Files\7-Zip\7z.exe"
:: The IBM Installation Manager root directory
IF "%IM_ROOT%." == "."        SET "IM_ROOT=C:\Program Files\Installation Manager\eclipse"
:: The location of the Installation Manager command line tool
SET "_IM_TOOL=%IM_ROOT%\tools\imcl.exe"
:: This will be set later in this command file.
SET _REPO_DIR=
:: Ensure %errorlevel% contains the last return code
SET errorlevel=
IF "%_DOWNLOAD%." == "."      SET _DOWNLOAD=0
IF "%_INSTALL%." == "."       SET _INSTALL=1
IF "%_DELETE%." == "."        SET _DELETE=0
IF "%_UPDATE%." == "."        SET _UPDATE=0
IF "%_MERGE%." == "."         SET _MERGE=0
IF "%_KEEP%." == "."          SET _KEEP=1
IF "%_USE_EXISTING%." == "."  SET _USE_EXISTING=1
IF "%_SOA_QUALIFIER%." == "." SET _SOA_QUALIFIER="local"
IF "%_SOA_VER%." == "."       SET _SOA_VER=11700
IF "%_ADMIN%." == "."         SET _ADMIN=1
IF "%_RC%." == "."            SET _RC=0
:: Optional: Location of an internal web server that contains the installer tar.gz file
IF "%_URL%." == "."           SET "_URL="
REM Is set to 1 only if --ins 1, --upd 1, or --del 1 is specified
SET _PERFORM=0

IF "%1" == "" (
   SET _RC=0
   GOTO :DISPLAY_SYNTAX
)

REM Default to running the installer
SET _ACTION=install

:LOOP
IF "%_DEBUG%." == "1." (
   @ECHO `1 is %~1`
)
IF NOT '%1' == ''  (
   
   SET _RC=0
   SET "_PARM_VALUE=%~2"
   
   IF "%1." == "--hel." (
      SET _ACTION=help
      GOTO :DISPLAY_SYNTAX
   ) ELSE IF "%1." == "--help." (
      SET _ACTION=help
      GOTO :DISPLAY_SYNTAX
   ) ELSE IF "%1." == "--ins." (
      SET _ACTION=install
      SHIFT
      GOTO :LOOP
   ) ELSE IF "%1." == "--install." (
      SET _ACTION=install
      SHIFT
      GOTO :LOOP
   ) ELSE IF "%1." == "--con." (
      SET _ACTION=console
      SHIFT
      GOTO :LOOP
   ) ELSE IF "%1." == "--console." (
      SET _ACTION=console
      SHIFT
      GOTO :LOOP
   ) ELSE IF "%1." == "--jav." (
      SET _ACTION=java
      SHIFT
      GOTO :LOOP
   ) ELSE IF "%1." == "--java." (
      SET _ACTION=java
      SHIFT
      GOTO :LOOP
   ) ELSE IF "%1." == "--sta." (
      SET _ACTION=status
      SHIFT
      GOTO :LOOP
   ) ELSE IF "%1." == "--status." (
      SET _ACTION=status
      SHIFT
      GOTO :LOOP
   ) ELSE IF '!_PARM_VALUE!' == '' (
      @ECHO 'ERROR: Parameters are 3 characters and require a value [--par value]. Found %1.'
      SET _RC=4
      GOTO :EXIT_CODE
   )

   SET _PARM_VALUE_BOOL=1
   IF "%_DEBUG%." == "1." (
      @ECHO `2 is %~2`
      @ECHO `_PARM_VALUE is !_PARM_VALUE!`
      @ECHO `3 is %~3`
   )

   IF "%1." == "--adm." (
      SET _ADMIN=!_PARM_VALUE!
   ) ELSE IF "%1." == "--com." (
      SET _SOA_COMPONENT=!_PARM_VALUE!
      SET _PARM_VALUE_BOOL=0
   ) ELSE IF "%1." == "--deb." (
      SET _DEBUG=!_PARM_VALUE!
      IF '!_PARM_VALUE!.' == '2.' (
         SET _PARM_VALUE_BOOL=0
         @ECHO ON
      )
   ) ELSE IF "%1." == "--del." (
      SET _DELETE=!_PARM_VALUE!
   ) ELSE IF "%1." == "--dow." (
      SET _DOWNLOAD=!_PARM_VALUE!
   ) ELSE IF "%1." == "--kee." (
      SET _KEEP=!_PARM_VALUE!
   ) ELSE IF "%1." == "--jre." (
      @ECHO Setting JRE_HOME to !_PARM_VALUE!
      SET JRE_HOME=!_PARM_VALUE!
      SET _PARM_VALUE_BOOL=0
   ) ELSE IF "%1." == "--jvm." (
      @ECHO Setting JVM_PATH to !_PARM_VALUE!
      SET JVM_PATH=!_PARM_VALUE!
      SET _PARM_VALUE_BOOL=0
   ) ELSE IF "%1." == "--mer." (
      SET _MERGE=!_PARM_VALUE!
   ) ELSE IF "%1." == "--oje." (
      @ECHO Setting JRE_HOME_OLD to !_PARM_VALUE!
      SET JRE_HOME_OLD=!_PARM_VALUE!
      SET _PARM_VALUE_BOOL=0
   ) ELSE IF "%1." == "--ojm." (
      @ECHO Setting JRE_PATH_OLD to !_PARM_VALUE!
      SET JVM_PATH_OLD=!_PARM_VALUE!
      SET _PARM_VALUE_BOOL=0
   ) ELSE IF "%1." == "--roo." (
      @ECHO 'Setting OPTIM_ROOT to !_PARM_VALUE!'
      SET 'OPTIM_ROOT=!_PARM_VALUE!'
      SET _PARM_VALUE_BOOL=0
   ) ELSE IF "%1." == "--qua." (
      SET _SOA_QUALIFIER=!_PARM_VALUE!
      SET _PARM_VALUE_BOOL=0
   ) ELSE IF "%1." == "--unv." (
      SET MAJOR_UNINSTALL_VERSION=!_PARM_VALUE!
      SET _PARM_VALUE_BOOL=0
   ) ELSE IF "%1." == "--upd." (
      SET _UPDATE=!_PARM_VALUE!
   ) ELSE IF "%1." == "--url." (
      SET _URL=!_PARM_VALUE!
      SET _PARM_VALUE_BOOL=0
   ) ELSE IF "%1." == "--use." (
      SET _USE_EXISTING=!_PARM_VALUE!
   ) ELSE IF "%1." == "--ver." (
      SET _SOA_VER=!_PARM_VALUE!
      SET _PARM_VALUE_BOOL=0
   ) ELSE (
      @ECHO 'Argument %1 is an unrecognized parameter.'
      SET _RC=99
      GOTO :EXIT_CODE
   )

   IF "!_PARM_VALUE_BOOL!" == "1" (
      IF '!_PARM_VALUE!' == '1' (
         SET _RC=0
      ) ELSE IF '!_PARM_VALUE!' == '0' (
         SET _RC=0
      ) ELSE (
         @ECHO '%1 requires a value of 0 or 1, found !_PARM_VALUE!.'
         SET _RC=99
         GOTO :EXIT_CODE
      )
   )
   SHIFT & SHIFT
   GOTO :LOOP
)

REM Use 1 to install as an administrator or 0 to install as a non-administrator user
REM depending on how Installation Manager is installed
IF "%_ADMIN%." == "0." (
   SET IM_INSTALL_MODE=nonAdmin
) ELSE (
   SET IM_INSTALL_MODE=admin
)

:: Ensure %errorlevel% contains the last return code
SET errorlevel=
IF "%_RC%." == "."            SET _RC=0

REM Ensure Installation Manager related variables are defined correctly 
CALL :VALIDATE_IM_ENVIRONMENT

IF NOT "%MAJOR_UNINSTALL_VERSION%." == "11.3.0.0." (
   IF NOT "%MAJOR_UNINSTALL_VERSION%." == "11.7.0.0." (
      @ECHO MAJOR_UNINSTALL_VERSION must be 11.3.0.0 or 11.7.0.0, found: %MAJOR_UNINSTALL_VERSION%.
      REM Ensure MAJOR_UNINSTALL_VERSION is valid if we are doing an uninstall
      IF "%UNINSTALL_DESIGNER%" == "1" (
         SET _RC=99
         GOTO EXIT
      )
      IF "%UNINSTALL_RUNTIME%" == "1" (
         SET _RC=99
         GOTO EXIT
      )
      IF "%UNINSTALL_SHARED%" == "1" (
         SET _RC=99
         GOTO EXIT
      )
   )
)

IF "!MAJOR_UNINSTALL_VERSION!." == "11.3.0.0." (
   SET "_FILE_LIST=installDesignerOLHelp.xml installRuntime.xml installShared.xml uninstallDesignerOLHelp.xml uninstallRuntime.xml uninstallShared11300.xml optim_installer_win.properties OptimSilentUninstall.bat SilentInstall.bat"
   SET _UNINSTALL_SHARED_XML=uninstallShared11300.xml
) ELSE (
   SET _UNINSTALL_SHARED_XML=uninstallShared.xml
   IF "%_INTERNAL%." == "1." (
      SET "_FILE_LIST=installDesignerOLHelp.xml installRuntime.xml installShared.xml installTest.xml uninstallDesignerOLHelp.xml uninstallRuntime.xml uninstallShared.xml uninstallTest.xml SilentInstall.bat"
   ) ELSE (   
      SET _FILE_LIST=installDesignerOLHelp.xml installRuntime.xml installShared.xml uninstallDesignerOLHelp.xml uninstallRuntime.xml uninstallShared.xml SilentInstall.bat
   )
)

REM Don't continue if a _RC GTR 1 was generated
IF "%_RC%" GTR "1" EXIT /B %_RC%

IF "%_ACTION%." == "status." (
   GOTO :DISPLAY_STATUS
   GOTO :EXIT_CODE
)


IF "%_ACTION%." == "console." (
   IF "%_DELETE%." == "1." (
      SET _DELETE=0
      @ECHO The option --del[ete] 1 is not permitted with --console and will be ignored.
   )
   IF "%_UPDATE%." == "1." (
      SET _UPDATE=0
      @ECHO The option --upd[ate] 1 is not permitted with --console and will be ignored.
   )
   IF "%_DOWNLOAD%." == "1." (
      SET _DOWNLOAD=0
      @ECHO The option --dow[nload] 1 is not permitted with --console and will be ignored.
      SET _RC=10
      GOTO :EXIT_CODE
   )
)

IF "%_ACTION%." == "console."               GOTO :CONSOLE_INSTALL

REM The remaining actions require a component
CALL :VALIDATE_ENVIRONMENT
IF "%_RC%" GTR "1" EXIT /B %_RC%

IF "%_ACTION%." == "java." (
   GOTO :UPDATE_JAVA
   GOTO :EXIT_CODE
)

IF "%_ACTION%." == "install." (
   IF "%_DELETE%." == "1."       SET _INSTALL=0
   IF "%_DELETE%." == "0."       SET _INSTALL=1
   IF "%_UPDATE%." == "1."       SET _INSTALL=1
)

IF "%_DELETE%." == "1." (
   IF "%_UPDATE%." == "1." (
      @ECHO The parameter --upd[ate] 1 is not permitted with --del[ete] 1.
      SET _RC=10
      GOTO :EXIT_CODE
   )
   IF "%_DOWNLOAD%." == "1." (
      @ECHO The parameter --dow[nload] 1 is not permitted with --del[ete] 1.
      SET _RC=10
      GOTO :EXIT_CODE
   )
)

CALL :DISPLAY_COMMAND

IF "%_DELETE%." == "1." (
   GOTO :SETREPO
)

IF "%_SOA_QUALIFIER%." == "local." (
   IF "%_SOA_COMPONENT%" == "designer" (
      SET _REPO=%OPTIM_FIXPACK_DESIGNER%
      SET _OFFERING=com.ibm.nex.designer
   )
   IF "%_SOA_COMPONENT%" == "runtime" (
      SET _REPO=%OPTIM_FIXPACK_RUNTIME%
      SET _OFFERING=com.ibm.nex.proxy
   )
   IF "%_SOA_COMPONENT%" == "test" (
      SET _REPO=%OPTIM_FIXPACK_TEST%
      SET _OFFERING=com.ibm.nex.test
   )
   IF "%_SOA_COMPONENT%" == "wasce" (
      SET _REPO=%OPTIM_FIXPACK_WASCE%
      SET _OFFERING=com.ibm.nex.was-ce
   )
   IF "%_SOA_COMPONENT%" == "web" (
      SET _REPO=%OPTIM_FIXPACK_WEB%
      SET _OFFERING=com.ibm.nex.console
   )
   IF "!_REPO!." == "." (
      @ECHO A repository was not defined for component "%_SOA_COMPONENT%".
     SET _RC=9
     GOTO :EXIT_CODE
   )
   IF NOT EXIST !_REPO!\repository.xml (
      @ECHO --qua local was specified but !_REPO!\repository.xml does not exist for component %_SOA_COMPONENT%.
      SET _RC=9
      GOTO :EXIT_CODE
   )

   @ECHO Looking for offering id='!_OFFERING!' version='
   FOR /f "delims=*" %%i in ('find /i "<offering id='!_OFFERING!' version='" ^< !_REPO%!\repository.xml' ) do (
      SET "_LINE=%%i"
      IF "%_DEBUG%." == "1." (
         @echo _LINE=!_LINE!
      )
      :: Change quote chars into    (ok so long as Parameter id does not contain 
      SET _LINE=!_LINE:'=!
      :: Extract text between 3rd and 4th  (originally 1 )
      FOR /f "tokens=3,4 delims=" %%a in ("!_LINE!") do ( echo %%b
         SET _SOA_QUALIFIER=%%b
      )
      @echo _SOA_QUALIFIER=!_SOA_QUALIFIER!
   )
)

IF "%_SOA_QUALIFIER%." == "remote." (
   SET _PROPERTIES_URL=%_URL%/latestBuild%_SOA_VER%.properties
   SET _PROPERTIES_FILE=%_SCRIPTS_DIR%\latestBuild%_SOA_VER%.properties

   @ECHO The parameter --qua[lifier] was not specified. Obtaining qualifier from !_PROPERTIES_FILE!

   @ECHO Validating !_PROPERTIES_URL!
   REM  2>&1 findstr /C:"HTTP/1.1 200"
   "%_WGET%" -S --spider "!_PROPERTIES_URL!"
   IF errorlevel 1 (
      @ECHO File !_PROPERTIES_URL! not found.
      SET _RC=7
      GOTO :EXIT_CODE
   )
   
   REM Remove previously downloaded properties file
   IF EXIST !_PROPERTIES_FILE! @ECHO Removing !_PROPERTIES_FILE!
   IF EXIST !_PROPERTIES_FILE! erase /F /Q  !_PROPERTIES_FILE!

   @ECHO Downloading !_PROPERTIES_URL!
   "%_WGET%" -nd -P%_SCRIPTS_DIR% !_PROPERTIES_URL!
   IF errorlevel 1 ( 
      @ECHO Failed to download !_PROPERTIES_URL!.
      SET _RC=8
      GOTO :EXIT_CODE
   )

   FOR /F "tokens=1,* delims==" %%G IN (!_PROPERTIES_FILE!) DO (
     IF "%%G"=="latestBuild.%_SOA_COMPONENT%.ver" (
        SET _SOA_QUALIFIER=%%H
        @ECHO Found a QUALIFIER of !_SOA_QUALIFIER! for %_SOA_COMPONENT%
     )
   )
   IF "!_SOA_QUALIFIER!" == "" (
      @ECHO The parameter --qua[lifier] was not specified and was not found in !_PROPERTIES_FILE!
      SET _RC=9
      GOTO :EXIT_CODE
   )
   REM The properties in the file have the SOA_VER in the ver property
   SET _TAR=%_SOA_COMPONENT%!_SOA_QUALIFIER!.tar
   SET _TAR_GZ=%_SOA_COMPONENT%!_SOA_QUALIFIER!.tar.gz
) ELSE (
   SET _TAR=%_SOA_COMPONENT%%_SOA_VER%_%_SOA_QUALIFIER%.tar
   SET _TAR_GZ=%_SOA_COMPONENT%%_SOA_VER%_%_SOA_QUALIFIER%.tar.gz
)
SET _INSTALLER=%_URL%/%_SOA_COMPONENT%/%_SOA_VER%dev/%_TAR_GZ%

:SETREPO

IF "%_SOA_COMPONENT%" == "designer" (
   SET _SHARED_DIR=%_SCRIPTS_DIR%\%_SOA_COMPONENT%
   SET _COMPONENT_DIR=%_SCRIPTS_DIR%\%_SOA_COMPONENT%
   IF "%_USE_EXISTING%" == "1" (
      SET _REPO_DIR=%OPTIM_FIXPACK_DESIGNER%
   ) ELSE (
      SET _REPO_DIR=%_SCRIPTS_DIR%\%_SOA_COMPONENT%\repo
   )
) ELSE IF "%_SOA_COMPONENT%" == "runtime" (
   SET _SHARED_DIR=%_SCRIPTS_DIR%\%_SOA_COMPONENT%
   SET _COMPONENT_DIR=%_SCRIPTS_DIR%\%_SOA_COMPONENT%
   IF "%_USE_EXISTING%" == "1" (
      SET _REPO_DIR=%OPTIM_FIXPACK_RUNTIME%
   ) ELSE (
      SET _REPO_DIR=%_SCRIPTS_DIR%\%_SOA_COMPONENT%\repo
   )
   IF "%OPTIM_PERMANENT_LICENSE%" == "true" (
      IF "%OPTIM_PERMANENT_DG_LICENSE%" == "true" (
         IF NOT EXIST "%OPTIM_PERMANENT_DG_LICENSE_DIRECTORY%\OPDG.LIC" (
            @ECHO The Optim Data Growth License file %OPTIM_PERMANENT_DG_LICENSE_DIRECTORY%\OPDG.LIC not found.
            SET _RC=15
            GOTO :EXIT_CODE
         )
      )
      IF "%OPTIM_PERMANENT_TDM_LICENSE%" == "true" (
         IF NOT EXIST "%OPTIM_PERMANENT_TDM_LICENSE_DIRECTORY%\OPTDM.LIC" (
            @ECHO The Optim Test Data Management License file %OPTIM_PERMANENT_TDM_LICENSE_DIRECTORY%\OPTDM.LIC not found.
            SET _RC=15
            GOTO :EXIT_CODE
         )
      )
      IF "%OPTIM_PERMANENT_DP_LICENSE%" == "true" (
         IF NOT EXIST "%OPTIM_PERMANENT_DP_LICENSE_DIRECTORY%\OPDP.LIC" (
            @ECHO The Optim Data Growth License file %OPTIM_PERMANENT_DP_LICENSE_DIRECTORY%\OPDP.LIC not found.
            SET _RC=15
            GOTO :EXIT_CODE
         )
      )
   )
) ELSE IF "%_SOA_COMPONENT%" == "test" (
   SET _SHARED_DIR=%_SCRIPTS_DIR%\%_SOA_COMPONENT%
   SET _COMPONENT_DIR=%_SCRIPTS_DIR%\%_SOA_COMPONENT%
   IF "%_USE_EXISTING%" == "1" (
      SET _REPO_DIR=%OPTIM_FIXPACK_TEST%
   ) ELSE (
      SET _REPO_DIR=%_SCRIPTS_DIR%\%_SOA_COMPONENT%\repo
   )
) ELSE IF "%_SOA_COMPONENT%" == "wasce" (
   SET _SHARED_DIR=%_SCRIPTS_DIR%\shared
   SET _COMPONENT_DIR=%_SCRIPTS_DIR%\shared\%_SOA_COMPONENT%
   IF "%_USE_EXISTING%" == "1" (
      SET _REPO_DIR=%OPTIM_FIXPACK_WASCE%
   ) ELSE (
      SET _REPO_DIR=%_SCRIPTS_DIR%\shared\%_SOA_COMPONENT%\repo
   )
) ELSE IF "%_SOA_COMPONENT%" == "web" (
   SET _SHARED_DIR=%_SCRIPTS_DIR%\shared
   SET _COMPONENT_DIR=%_SCRIPTS_DIR%\shared\%_SOA_COMPONENT%
   IF "%_USE_EXISTING%" == "1" (
      SET _REPO_DIR=%OPTIM_FIXPACK_WEB%
   ) ELSE (
      SET _REPO_DIR=%_SCRIPTS_DIR%\shared\%_SOA_COMPONENT%\repo
   )
) ELSE (
   @ECHO The component name %_SOA_COMPONENT% is not designer, runtime, or web.
   SET _RC=11
   GOTO :EXIT_CODE
)  
IF NOT EXIST "%_SHARED_DIR%" MKDIR "%_SHARED_DIR%"
IF NOT EXIST "%_COMPONENT_DIR%" MKDIR "%_COMPONENT_DIR%"
IF NOT EXIST "%_REPO_DIR%" MKDIR "%_REPO_DIR%"

IF "%_DELETE%." == "1." (
   GOTO :COPY_FILES
)

REM Determine if the TAR.GZ file exists 
IF EXIST "%_SCRIPTS_DIR%\%_TAR_GZ%" (
   @ECHO Tar file %_SCRIPTS_DIR%\%_TAR_GZ% was previously downloaded
) ELSE IF "%_DOWNLOAD%" == "1" (
   IF "%_USE_EXISTING%" == "1" (
      @ECHO The parameter --dow[load] 1 can not be used with --use[ existing] 1.
      SET _RC=11
      GOTO :EXIT_CODE
   )
   @ECHO Validating %_INSTALLER%
   REM  2>&1 findstr /C:"HTTP/1.1 200"
   %_WGET% -S --spider "%_INSTALLER%"
   IF errorlevel 1 (
      @ECHO File %_INSTALLER% not found.
      SET _RC=12
      GOTO :EXIT_CODE
   )
   
   REM Remove all files in component directory UNLESS we are merging
   IF "%_MERGE%" == "0" @ECHO Removing %_SHARED_DIR%\*.*
   IF "%_MERGE%" == "0" erase /F /Q /S %_SHARED_DIR%\*.*

   @ECHO Downloading %_INSTALLER%
   %_WGET% -nd -P%_SCRIPTS_DIR% %_INSTALLER%
   IF errorlevel 1 ( 
      @ECHO Failed to download %_INSTALLER%.
      SET _RC=13
      GOTO :EXIT_CODE
   )
)

IF "%_USE_EXISTING%" == "0" (
   IF NOT EXIST "%_SCRIPTS_DIR%\%_TAR_GZ%" (
      @ECHO Can't find tar file %_SCRIPTS_DIR%\%_TAR_GZ%
      SET _RC=14
      GOTO :EXIT_CODE
   )

   IF EXIST "%_REPO_DIR%" @ECHO Clearing repository "%_REPO_DIR%"\*.*
   IF EXIST "%_REPO_DIR%" erase /Q /F /S "%_REPO_DIR%"\*.*
)

@ECHO Validating "%_REPO_DIR%\repository.config
IF NOT EXIST "%_REPO_DIR%\repository.config" (
    IF NOT EXIST "%_REPO_DIR%" MKDIR "%_REPO_DIR%"

    REM First ensure the downloaded .tar.gz file exists
    IF EXIST "%_SCRIPTS_DIR%\%_TAR_GZ%" (
        REM Next, determine if the enclosed .tar was extracted
        IF NOT EXIST "%_REPO_DIR%\%_TAR%" (
            @ECHO Extracting %_SCRIPTS_DIR%\%_TAR_GZ% to %_REPO_DIR%
            "%_ZIP%" x %_SCRIPTS_DIR%\%_TAR_GZ% -o%_REPO_DIR%
            IF errorlevel 1 (
               @ECHO Failed to extract %_SCRIPTS_DIR%\%_TAR_GZ%
               SET _RC=17
               GOTO :EXIT_CODE
            )
        )
        @ECHO Extracting %_REPO_DIR%\%_TAR% to %_REPO_DIR%
        "%_ZIP%" x %_REPO_DIR%\%_TAR% -o%_REPO_DIR%
        IF errorlevel 1 (
           @ECHO Failed to extract %_REPO_DIR%\%_TAR%
           SET _RC=17
           GOTO :EXIT_CODE
        )
    ) ELSE (
        @ECHO Failed to find %_SCRIPTS_DIR%\%_TAR_GZ%
        SET _RC=17
        GOTO :EXIT_CODE
    )
)

IF NOT EXIST "%_REPO_DIR%\repository.config" (
   @ECHO Error "%_REPO_DIR%\repository.config" was not extracted!
   SET _RC=18
   GOTO :EXIT_CODE
)

:COPY_FILES

:: SETLOCAL EnableDelayedExpansion
:: SETLOCAL EnableExtensions
IF "%_MERGE%" == "0" (
   FOR %%F IN (%_FILE_LIST%) DO (
      @ECHO COPYING "%_SCRIPTS_DIR%\%%F" to "%_SHARED_DIR%\%%F"
      COPY /Y "%_SCRIPTS_DIR%\%%F" "%_SHARED_DIR%\%%F"
   )
)
REM Internal Use Only
IF "%_COMPONENT%" == "java" (
   FOR %%F IN (%_FILE_LIST_JAVA%) DO (
      @ECHO COPYING "%_SCRIPTS_DIR%\%%F" to "%_SHARED_DIR%\%%F"
      COPY /Y "%_SCRIPTS_DIR%\%%F" "%_SHARED_DIR%\%%F"
   )
)
:: ENDLOCAL

:REPLACE

:: Because the string INSTALL_component= is present in UNINSTALL_component=
:: We need to perform multiple steps
:: First turn everything off
SET UNINSTALL_DESIGNER=0
SET INSTALL_DESIGNER=0
SET UNINSTALL_RUNTIME=0
SET INSTALL_RUNTIME=0
REM TEST is for internal use ONLY
SET UNINSTALL_TEST=0
SET INSTALL_TEST=0
SET UNINSTALL_SHARED=0
SET INSTALL_SHARED=0
IF "%_UPDATE%" == "1" (
   SET _PERFORM=1
   REM On an update, disable the UNINSTALL flag and keep the install flag for the specified component
   IF "%_SOA_COMPONENT%" == "designer" (
      SET INSTALL_DESIGNER=1
   ) ELSE IF "%_SOA_COMPONENT%" == "runtime"  (
      SET INSTALL_RUNTIME=1
   ) ELSE IF "%_SOA_COMPONENT%" == "test"  (
      SET INSTALL_TEST=1
   ) ELSE (
      REM Web (and WAS-CE in 11.3.0.8 only) must be installed together.
      SET INSTALL_SHARED=1
   )
) ELSE IF "%_INSTALL%" == "1" (
   SET _PERFORM=1
   REM On an install, enable both the UNINSTALL and INSTALL flags for the specified component
   IF "%_SOA_COMPONENT%" == "designer" (
      SET UNINSTALL_DESIGNER=1
      SET INSTALL_DESIGNER=1
   ) ELSE IF "%_SOA_COMPONENT%" == "runtime" (
      SET UNINSTALL_RUNTIME=1
      SET INSTALL_RUNTIME=1
   ) ELSE IF "%_SOA_COMPONENT%" == "test" (
      SET UNINSTALL_TEST=1
      SET INSTALL_TEST=1
   ) ELSE (
      SET UNINSTALL_SHARED=1
      SET INSTALL_SHARED=1
   )
) ELSE IF "%_DELETE%" == "1" (
   SET _PERFORM=1
   REM On a delete, only enable the UNINSTALL flag for the specified component
   IF "%_SOA_COMPONENT%" == "designer" (
      SET UNINSTALL_DESIGNER=1
   ) ELSE IF "%_SOA_COMPONENT%" == "runtime" (
      SET UNINSTALL_RUNTIME=1
   ) ELSE IF "%_SOA_COMPONENT%" == "test" (
      SET UNINSTALL_TEST=1
   ) ELSE (
      SET UNINSTALL_SHARED=1
   )
) ELSE (
   REM We're not doing an update or an install
   REM Keep everything off
   SET _PERFORM=0
)

@ECHO CD "%_SHARED_DIR%"
IF NOT "%_PERFORM%." == "1." GOTO :DONE
CD "%_SHARED_DIR%"

IF NOT EXIST "%_SHARED_DIR%\SilentInstall.bat" (
   @ECHO "%_SHARED_DIR%"\SilentInstall.bat not found.
   SET _RC=20
   GOTO :EXIT_CODE
)

@REM Create a timestamp in the format YYYMMDD_HHMM
@REM Use FOR /F to 'break out' the components of %DATE% and %TIME%, assuming 'yyyy/mm/dd' format date i.e.
FOR /F "tokens=1-6* delims=.:-/ " %%i IN ("%DATE% %TIME%") DO SET "YYYY=%%i"& SET "MM=%%j"& SET "DD=%%k"& SET "HH=%%l"& SET "MI=%%m"
@REM Switch the year and day if appropriate
IF NOT "X%DD:~2%" == "X" Set "YYYY=%DD%"& Set "DD=%YYYY%"
@REM Create a timestamp in yyyymmdd_hhmm
SET "TIME_STAMP=%YYYY%%MM%%DD%_%HH%%MI%"

IF "%_SOA_COMPONENT%" == "runtime" (
   @REM Backup the current OptimConfigClient.pst if one exists
   IF EXIST "%OPTIM_ROOT%\rt\OptimConfigClient.pst" (
      @ECHO COPY %OPTIM_ROOT%\rt\OptimConfigClient.pst %_SCRIPTS_DIR%\OptimConfigClient_%TIME_STAMP%.pst
      COPY "%OPTIM_ROOT%\rt\OptimConfigClient.pst" "%_SCRIPTS_DIR%\OptimConfigClient_%TIME_STAMP%.pst"
   )
   @REM Backup the current OptimConfigServer.pst if one exists
   IF EXIST "%OPTIM_ROOT%\rt\OptimConfigServer.pst" (
      @ECHO COPY %OPTIM_ROOT%\rt\OptimConfigServer.pst %_SCRIPTS_DIR%\OptimConfigServer_%TIME_STAMP%.pst
      COPY "%OPTIM_ROOT%\rt\OptimConfigServer.pst" "%_SCRIPTS_DIR%\OptimConfigServer_%TIME_STAMP%.pst"
   )
   @REM Backup the current OptimConfigClientPreserve.pst if one exists
   IF EXIST "%OPTIM_ROOT%\rt\OptimConfigClientPreserve.pst" (
      @ECHO COPY %OPTIM_ROOT%\rt\OptimConfigClientPreserve.pst %_SCRIPTS_DIR%\OptimConfigClientPreserve_%TIME_STAMP%.pst
      COPY "%OPTIM_ROOT%\rt\OptimConfigClientPreserve.pst" "%_SCRIPTS_DIR%\OptimConfigClientPreserve_%TIME_STAMP%.pst"
   )
   @REM Backup the current OptimConfigServerPreserve.pst if one exists
   IF EXIST "%OPTIM_ROOT%\rt\OptimConfigServerPreserve.pst" (
      @ECHO COPY %OPTIM_ROOT%\rt\OptimConfigServerPreserve.pst %_SCRIPTS_DIR%\OptimConfigServerPreserve_%TIME_STAMP%.pst
      COPY "%OPTIM_ROOT%\rt\OptimConfigServerPreserve.pst" "%_SCRIPTS_DIR%\OptimConfigServerPreserve_%TIME_STAMP%.pst"
   )
)
@echo Calling %_SHARED_DIR%\SilentInstall.bat.... 
CALL "%_SHARED_DIR%\SilentInstall.bat"
SET _RC=%ERRORLEVEL%

IF "%_SOA_COMPONENT%" == "runtime" (
   @ECHO cd "%OPTIM_ROOT%\rt"
   cd "%OPTIM_ROOT%\rt"
   @REM Restore the backup OptimConfigClient, OptimConfigServer, OptimConfigClientPreserve, and OptimConfigServerPreserve files
   IF EXIST "%_SCRIPTS_DIR%\OptimConfigClient_%TIME_STAMP%.pst" (
      IF EXIST "%OPTIM_ROOT%\rt\OptimConfigClient.pst" ren OptimConfigClient.pst OptimConfigClient_%TIME_STAMP%_BAK.pst
      @ECHO copy /Y "%_SCRIPTS_DIR%\OptimConfigClient_%TIME_STAMP%.pst" "%OPTIM_ROOT%\rt\OptimConfigClient.pst"
      copy /Y "%_SCRIPTS_DIR%\OptimConfigClient_%TIME_STAMP%.pst" "%OPTIM_ROOT%\rt\OptimConfigClient.pst"
   )
   IF EXIST "%_SCRIPTS_DIR%\OptimConfigServer_%TIME_STAMP%.pst" (
      IF EXIST "%OPTIM_ROOT%\rt\OptimConfigServer.pst" ren OptimConfigServer.pst OptimConfigServer_%TIME_STAMP%_BAK.pst
      @ECHO copy /Y %_SCRIPTS_DIR%\OptimConfigServer_%TIME_STAMP%.pst %OPTIM_ROOT%\rt\OptimConfigServer.pst
      copy /Y "%_SCRIPTS_DIR%\OptimConfigServer_%TIME_STAMP%.pst" "%OPTIM_ROOT%\rt\OptimConfigServer.pst"
   )
   IF EXIST "%_SCRIPTS_DIR%\OptimConfigClientPreserve_%TIME_STAMP%.pst" (
      IF EXIST "%OPTIM_ROOT%\rt\OptimConfigClientPreserve.pst" ren OptimConfigClientPreserve.pst OptimConfigClientPreserve_%TIME_STAMP%_BAK.pst
      @ECHO copy /Y "%_SCRIPTS_DIR%\OptimConfigClientPreserve_%TIME_STAMP%.pst" "%OPTIM_ROOT%\rt\OptimConfigClientPreserve.pst"
      copy /Y "%_SCRIPTS_DIR%\OptimConfigClientPreserve_%TIME_STAMP%.pst" "%OPTIM_ROOT%\rt\OptimConfigClientPreserve.pst"
   )
   IF EXIST "%_SCRIPTS_DIR%\OptimConfigServerPreserve_%TIME_STAMP%.pst" (
      IF EXIST "%OPTIM_ROOT%\rt\OptimConfigServerPreserve.pst" ren OptimConfigServerPreserve.pst OptimConfigServerPreserve_%TIME_STAMP%_BAK.pst
      @ECHO copy /Y %_SCRIPTS_DIR%\OptimConfigServerPreserve_%TIME_STAMP%.pst %OPTIM_ROOT%\rt\OptimConfigServerPreserve.pst
      copy /Y "%_SCRIPTS_DIR%\OptimConfigServerPreserve_%TIME_STAMP%.pst" "%OPTIM_ROOT%\rt\OptimConfigServerPreserve.pst"
   )
)
IF NOT "%_RC%" == "0" (
   @ECHO "%_SHARED_DIR%"\SilentInstall.bat failed.
   GOTO :DONE
)

:DONE
IF "%_PERFORM%." == "1." (
   REM Always delete the tar file.
   IF NOT "%_TAR%." == "." (
      IF EXIST "%_REPO_DIR%\%_TAR%" (
         @ECHO Removing %_REPO_DIR%\%_TAR%
         erase /Q /F "%_REPO_DIR%\%_TAR%"
      )
      IF "%_RC%." == "0." (
         REM If keep was not specified, then delete the tar.gz file
         IF "%_KEEP%." == "0." (
            IF EXIST "%_SCRIPTS_DIR%\%_TAR_GZ%" (
               @ECHO Removing  %_SCRIPTS_DIR%\%_TAR_GZ%
               erase /Q /F "%_SCRIPTS_DIR%\%_TAR_GZ%"
            )
         )
      )
   )
)

GOTO :DISPLAY_STATUS
GOTO :EXIT_CODE
